Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2alphaTransformedUserEventsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2alphaTransformedUserEventsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Metadata related to transform user events operation.
Instance Attribute Summary collapse
-
#source_events_count ⇒ Fixnum
Count of entries in the source user events BigQuery table.
-
#transformed_events_count ⇒ Fixnum
Count of entries in the transformed user events BigQuery table, which could be different from the actually imported number of user events.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaTransformedUserEventsMetadata
constructor
A new instance of GoogleCloudRetailV2alphaTransformedUserEventsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaTransformedUserEventsMetadata
Returns a new instance of GoogleCloudRetailV2alphaTransformedUserEventsMetadata.
2365 2366 2367 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_events_count ⇒ Fixnum
Count of entries in the source user events BigQuery table.
Corresponds to the JSON property sourceEventsCount
2357 2358 2359 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2357 def source_events_count @source_events_count end |
#transformed_events_count ⇒ Fixnum
Count of entries in the transformed user events BigQuery table, which could be
different from the actually imported number of user events.
Corresponds to the JSON property transformedEventsCount
2363 2364 2365 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2363 def transformed_events_count @transformed_events_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2370 2371 2372 2373 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2370 def update!(**args) @source_events_count = args[:source_events_count] if args.key?(:source_events_count) @transformed_events_count = args[:transformed_events_count] if args.key?(:transformed_events_count) end |