Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaAddFulfillmentPlacesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Request message for ProductService.AddFulfillmentPlaces method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaAddFulfillmentPlacesRequest

Returns a new instance of GoogleCloudRetailV2betaAddFulfillmentPlacesRequest.



2535
2536
2537
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#add_timeString

The time when the fulfillment updates are issued, used to prevent out-of-order updates on fulfillment information. If not provided, the internal system time will be used. Corresponds to the JSON property addTime

Returns:

  • (String)


2501
2502
2503
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2501

def add_time
  @add_time
end

#allow_missingBoolean Also known as: allow_missing?

If set to true, and the Product is not found, the fulfillment information will still be processed and retained for at most 1 day and processed once the Product is created. If set to false, a NOT_FOUND error is returned if the Product is not found. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


2509
2510
2511
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2509

def allow_missing
  @allow_missing
end

#place_idsArray<String>

Required. The IDs for this type, such as the store IDs for "pickup-in-store" or the region IDs for "same-day-delivery" to be added for this type. Duplicate IDs will be automatically ignored. At least 1 value is required, and a maximum of 2000 values are allowed. Each value must be a string with a length limit of 10 characters, matching the pattern [a-zA-Z0-9_-]+, such as "store1" or " REGION-2". Otherwise, an INVALID_ARGUMENT error is returned. If the total number of place IDs exceeds 2000 for this type after adding, then the update will be rejected. Corresponds to the JSON property placeIds

Returns:

  • (Array<String>)


2522
2523
2524
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2522

def place_ids
  @place_ids
end

#typeString

Required. The fulfillment type, including commonly used types (such as pickup in store and same day delivery), and custom types. Supported values: * "pickup- in-store" * "ship-to-store" * "same-day-delivery" * "next-day-delivery" * " custom-type-1" * "custom-type-2" * "custom-type-3" * "custom-type-4" * "custom- type-5" If this field is set to an invalid value other than these, an INVALID_ARGUMENT error is returned. This field directly corresponds to Product. fulfillment_info.type. Corresponds to the JSON property type

Returns:

  • (String)


2533
2534
2535
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2533

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2540
2541
2542
2543
2544
2545
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2540

def update!(**args)
  @add_time = args[:add_time] if args.key?(:add_time)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @place_ids = args[:place_ids] if args.key?(:place_ids)
  @type = args[:type] if args.key?(:type)
end