Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaAddLocalInventoriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaAddLocalInventoriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Request message for ProductService.AddLocalInventories method.
Instance Attribute Summary collapse
-
#add_mask ⇒ String
Indicates which inventory fields in the provided list of LocalInventory to update.
-
#add_time ⇒ String
The time when the inventory updates are issued.
-
#allow_missing ⇒ Boolean
(also: #allow_missing?)
If set to true, and the Product is not found, the local inventory will still be processed and retained for at most 1 day and processed once the Product is created.
-
#local_inventories ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaLocalInventory>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaAddLocalInventoriesRequest
constructor
A new instance of GoogleCloudRetailV2betaAddLocalInventoriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaAddLocalInventoriesRequest
Returns a new instance of GoogleCloudRetailV2betaAddLocalInventoriesRequest.
2616 2617 2618 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_mask ⇒ String
Indicates which inventory fields in the provided list of LocalInventory to
update. The field is updated to the provided value. If a field is set while
the place does not have a previous local inventory, the local inventory at
that store is created. If a field is set while the value of that field is not
provided, the original field value, if it exists, is deleted. If the mask is
not set or set with empty paths, all inventory fields will be updated. If an
unsupported or unknown field is provided, an INVALID_ARGUMENT error is
returned and the entire update will be ignored.
Corresponds to the JSON property addMask
2592 2593 2594 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2592 def add_mask @add_mask end |
#add_time ⇒ String
The time when the inventory updates are issued. Used to prevent out-of-order
updates on local inventory fields. If not provided, the internal system time
will be used.
Corresponds to the JSON property addTime
2599 2600 2601 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2599 def add_time @add_time end |
#allow_missing ⇒ Boolean Also known as: allow_missing?
If set to true, and the Product is not found, the local inventory will still
be processed and retained for at most 1 day and processed once the Product is
created. If set to false, a NOT_FOUND error is returned if the Product is not
found.
Corresponds to the JSON property allowMissing
2607 2608 2609 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2607 def allow_missing @allow_missing end |
#local_inventories ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaLocalInventory>
Required. A list of inventory information at difference places. Each place is
identified by its place ID. At most 3000 inventories are allowed per request.
Corresponds to the JSON property localInventories
2614 2615 2616 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2614 def local_inventories @local_inventories end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2621 2622 2623 2624 2625 2626 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2621 def update!(**args) @add_mask = args[:add_mask] if args.key?(:add_mask) @add_time = args[:add_time] if args.key?(:add_time) @allow_missing = args[:allow_missing] if args.key?(:allow_missing) @local_inventories = args[:local_inventories] if args.key?(:local_inventories) end |