Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCollectUserEventRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Request message for CollectUserEvent method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaCollectUserEventRequest

Returns a new instance of GoogleCloudRetailV2betaCollectUserEventRequest.



3372
3373
3374
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etsFixnum

The event timestamp in milliseconds. This prevents browser caching of otherwise identical get requests. The name is abbreviated to reduce the payload bytes. Corresponds to the JSON property ets

Returns:

  • (Fixnum)


3343
3344
3345
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3343

def ets
  @ets
end

#prebuilt_ruleString

The prebuilt rule name that can convert a specific type of raw_json. For example: "ga4_bq" rule for the GA4 user event schema. Corresponds to the JSON property prebuiltRule

Returns:

  • (String)


3349
3350
3351
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3349

def prebuilt_rule
  @prebuilt_rule
end

#raw_jsonString

An arbitrary serialized JSON string that contains necessary information that can comprise a user event. When this field is specified, the user_event field will be ignored. Note: line-delimited JSON is not supported, a single JSON only. Corresponds to the JSON property rawJson

Returns:

  • (String)


3357
3358
3359
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3357

def raw_json
  @raw_json
end

#uriString

The URL including cgi-parameters but excluding the hash fragment with a length limit of 5,000 characters. This is often more useful than the referer URL, because many browsers only send the domain for 3rd party requests. Corresponds to the JSON property uri

Returns:

  • (String)


3364
3365
3366
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3364

def uri
  @uri
end

#user_eventString

Required. URL encoded UserEvent proto with a length limit of 2,000,000 characters. Corresponds to the JSON property userEvent

Returns:

  • (String)


3370
3371
3372
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3370

def user_event
  @user_event
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3377
3378
3379
3380
3381
3382
3383
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3377

def update!(**args)
  @ets = args[:ets] if args.key?(:ets)
  @prebuilt_rule = args[:prebuilt_rule] if args.key?(:prebuilt_rule)
  @raw_json = args[:raw_json] if args.key?(:raw_json)
  @uri = args[:uri] if args.key?(:uri)
  @user_event = args[:user_event] if args.key?(:user_event)
end