Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCompleteQueryResponseCompletionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Resource that represents completion results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaCompleteQueryResponseCompletionResult

Returns a new instance of GoogleCloudRetailV2betaCompleteQueryResponseCompletionResult.



3514
3515
3516
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCustomAttribute>

Custom attributes for the suggestion term. * For user-data, the attributes are additional custom attributes ingested through BigQuery. * For cloud- retail, the attributes are product attributes generated by Cloud Retail. It requires UserEvent.product_details is imported properly. Corresponds to the JSON property attributes



3507
3508
3509
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3507

def attributes
  @attributes
end

#suggestionString

The suggestion for the query. Corresponds to the JSON property suggestion

Returns:

  • (String)


3512
3513
3514
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3512

def suggestion
  @suggestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3519
3520
3521
3522
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3519

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
end