Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCompletionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Catalog level autocomplete config for customers to customize autocomplete feature's settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaCompletionConfig

Returns a new instance of GoogleCloudRetailV2betaCompletionConfig.



3623
3624
3625
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowlist_input_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaCompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property allowlistInputConfig



3552
3553
3554
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3552

def allowlist_input_config
  @allowlist_input_config
end

#auto_learningBoolean Also known as: auto_learning?

If set to true, the auto learning function is enabled. Auto learning uses user data to generate suggestions using ML techniques. Default value is false. Only after enabling auto learning can users use cloud-retail data in CompleteQueryRequest. Corresponds to the JSON property autoLearning

Returns:

  • (Boolean)


3560
3561
3562
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3560

def auto_learning
  @auto_learning
end

#denylist_input_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaCompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property denylistInputConfig



3566
3567
3568
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3566

def denylist_input_config
  @denylist_input_config
end

#last_allowlist_import_operationString

Output only. Name of the LRO corresponding to the latest allowlist import. Can use GetOperation API to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastAllowlistImportOperation

Returns:

  • (String)


3573
3574
3575
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3573

def last_allowlist_import_operation
  @last_allowlist_import_operation
end

#last_denylist_import_operationString

Output only. Name of the LRO corresponding to the latest denylist import. Can use GetOperation API to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastDenylistImportOperation

Returns:

  • (String)


3580
3581
3582
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3580

def last_denylist_import_operation
  @last_denylist_import_operation
end

#last_suggestions_import_operationString

Output only. Name of the LRO corresponding to the latest suggestion terms list import. Can use GetOperation API method to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastSuggestionsImportOperation

Returns:

  • (String)


3587
3588
3589
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3587

def last_suggestions_import_operation
  @last_suggestions_import_operation
end

#matching_orderString

Specifies the matching order for autocomplete suggestions, e.g., a query consisting of 'sh' with 'out-of-order' specified would suggest "women's shoes", whereas a query of 'red s' with 'exact-prefix' specified would suggest "red shoes". Currently supported values: * 'out-of-order' * 'exact-prefix' Default value: 'exact-prefix'. Corresponds to the JSON property matchingOrder

Returns:

  • (String)


3596
3597
3598
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3596

def matching_order
  @matching_order
end

#max_suggestionsFixnum

The maximum number of autocomplete suggestions returned per term. Default value is 20. If left unset or set to 0, then will fallback to default value. Value range is 1 to 20. Corresponds to the JSON property maxSuggestions

Returns:

  • (Fixnum)


3603
3604
3605
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3603

def max_suggestions
  @max_suggestions
end

#min_prefix_lengthFixnum

The minimum number of characters needed to be typed in order to get suggestions. Default value is 2. If left unset or set to 0, then will fallback to default value. Value range is 1 to 20. Corresponds to the JSON property minPrefixLength

Returns:

  • (Fixnum)


3610
3611
3612
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3610

def min_prefix_length
  @min_prefix_length
end

#nameString

Required. Immutable. Fully qualified name projects/*/locations/*/catalogs/*/ completionConfig Corresponds to the JSON property name

Returns:

  • (String)


3616
3617
3618
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3616

def name
  @name
end

#suggestions_input_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaCompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property suggestionsInputConfig



3621
3622
3623
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3621

def suggestions_input_config
  @suggestions_input_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3628
3629
3630
3631
3632
3633
3634
3635
3636
3637
3638
3639
3640
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3628

def update!(**args)
  @allowlist_input_config = args[:allowlist_input_config] if args.key?(:allowlist_input_config)
  @auto_learning = args[:auto_learning] if args.key?(:auto_learning)
  @denylist_input_config = args[:denylist_input_config] if args.key?(:denylist_input_config)
  @last_allowlist_import_operation = args[:last_allowlist_import_operation] if args.key?(:last_allowlist_import_operation)
  @last_denylist_import_operation = args[:last_denylist_import_operation] if args.key?(:last_denylist_import_operation)
  @last_suggestions_import_operation = args[:last_suggestions_import_operation] if args.key?(:last_suggestions_import_operation)
  @matching_order = args[:matching_order] if args.key?(:matching_order)
  @max_suggestions = args[:max_suggestions] if args.key?(:max_suggestions)
  @min_prefix_length = args[:min_prefix_length] if args.key?(:min_prefix_length)
  @name = args[:name] if args.key?(:name)
  @suggestions_input_config = args[:suggestions_input_config] if args.key?(:suggestions_input_config)
end