Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCondition
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Metadata that is used to define a condition that triggers an action. A valid condition must specify at least one of 'query_terms' or 'products_filter'. If multiple fields are specified, the condition is met if all the fields are satisfied e.g. if a set of query terms and product_filter are set, then only items matching the product_filter for requests with a query matching the query terms wil get boosted.
Instance Attribute Summary collapse
-
#active_time_range ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConditionTimeRange>
Range of time(s) specifying when Condition is active.
-
#page_categories ⇒ Array<String>
Used to support browse uses cases.
-
#query_terms ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConditionQueryTerm>
A list (up to 10 entries) of terms to match the query on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaCondition
constructor
A new instance of GoogleCloudRetailV2betaCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaCondition
Returns a new instance of GoogleCloudRetailV2betaCondition.
3723 3724 3725 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3723 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_time_range ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConditionTimeRange>
Range of time(s) specifying when Condition is active. Condition true if any
time range matches.
Corresponds to the JSON property activeTimeRange
3708 3709 3710 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3708 def active_time_range @active_time_range end |
#page_categories ⇒ Array<String>
Used to support browse uses cases. A list (up to 10 entries) of categories or
departments. The format should be the same as UserEvent.page_categories;
Corresponds to the JSON property pageCategories
3714 3715 3716 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3714 def page_categories @page_categories end |
#query_terms ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConditionQueryTerm>
A list (up to 10 entries) of terms to match the query on. If not specified,
match all queries. If many query terms are specified, the condition is matched
if any of the terms is a match (i.e. using the OR operator).
Corresponds to the JSON property queryTerms
3721 3722 3723 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3721 def query_terms @query_terms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3728 3729 3730 3731 3732 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3728 def update!(**args) @active_time_range = args[:active_time_range] if args.key?(:active_time_range) @page_categories = args[:page_categories] if args.key?(:page_categories) @query_terms = args[:query_terms] if args.key?(:query_terms) end |