Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response message for ConversationalSearchService.ConversationalSearch method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaConversationalSearchResponse

Returns a new instance of GoogleCloudRetailV2betaConversationalSearchResponse.



4164
4165
4166
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idString

Conversation UUID. This field will be stored in client side storage to maintain the conversation session with server and will be used for next search request's ConversationalSearchRequest.conversation_id to restore conversation state in server. Corresponds to the JSON property conversationId

Returns:

  • (String)


4125
4126
4127
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4125

def conversation_id
  @conversation_id
end

#conversational_filtering_resultGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchResponseConversationalFilteringResult

This field specifies all related information that is needed on client side for UI rendering of conversational filtering search. Corresponds to the JSON property conversationalFilteringResult



4131
4132
4133
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4131

def conversational_filtering_result
  @conversational_filtering_result
end

#conversational_text_responseString

The conversational answer-based text response generated by the Server. Corresponds to the JSON property conversationalTextResponse

Returns:

  • (String)


4136
4137
4138
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4136

def conversational_text_response
  @conversational_text_response
end

#followup_questionGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchResponseFollowupQuestion

The conversational followup question generated for Intent refinement. Corresponds to the JSON property followupQuestion



4141
4142
4143
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4141

def followup_question
  @followup_question
end

#refined_searchArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchResponseRefinedSearch>

The proposed refined search queries. They can be used to fetch the relevant search results. When using CONVERSATIONAL_FILTER_ONLY mode, the refined_query from search response will be populated here. Corresponds to the JSON property refinedSearch



4148
4149
4150
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4148

def refined_search
  @refined_search
end

#stateString

Output only. The state of the response generation. Corresponds to the JSON property state

Returns:

  • (String)


4153
4154
4155
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4153

def state
  @state
end

#user_query_typesArray<String>

The types Retail classifies the search query as. Supported values are: - " ORDER_SUPPORT" - "SIMPLE_PRODUCT_SEARCH" - "INTENT_REFINEMENT" - " PRODUCT_DETAILS" - "PRODUCT_COMPARISON" - "DEALS_AND_COUPONS" - " STORE_RELEVANT" - "BLOCKLISTED" - "BEST_PRODUCT" - "RETAIL_SUPPORT" - " DISABLED" Corresponds to the JSON property userQueryTypes

Returns:

  • (Array<String>)


4162
4163
4164
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4162

def user_query_types
  @user_query_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4169
4170
4171
4172
4173
4174
4175
4176
4177
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4169

def update!(**args)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @conversational_filtering_result = args[:conversational_filtering_result] if args.key?(:conversational_filtering_result)
  @conversational_text_response = args[:conversational_text_response] if args.key?(:conversational_text_response)
  @followup_question = args[:followup_question] if args.key?(:followup_question)
  @refined_search = args[:refined_search] if args.key?(:refined_search)
  @state = args[:state] if args.key?(:state)
  @user_query_types = args[:user_query_types] if args.key?(:user_query_types)
end