Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchResponseConversationalFilteringResultAdditionalFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Additional filter that client side need to apply.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaConversationalSearchResponseConversationalFilteringResultAdditionalFilter

Returns a new instance of GoogleCloudRetailV2betaConversationalSearchResponseConversationalFilteringResultAdditionalFilter.



4217
4218
4219
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#product_attribute_valueGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeValue

Product attribute which structured by an attribute name and value. This structure is used in conversational search filters and answers. For example, if we have name=color and value=red, this means that the color is red. Corresponds to the JSON property productAttributeValue



4215
4216
4217
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4215

def product_attribute_value
  @product_attribute_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4222
4223
4224
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4222

def update!(**args)
  @product_attribute_value = args[:product_attribute_value] if args.key?(:product_attribute_value)
end