Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExportProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response of the ExportProductsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaExportProductsResponse

Returns a new instance of GoogleCloudRetailV2betaExportProductsResponse.



4612
4613
4614
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4599
4600
4601
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4599

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaExportErrorsConfig

Configuration of destination for Export related errors. Corresponds to the JSON property errorsConfig



4604
4605
4606
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4604

def errors_config
  @errors_config
end

#output_resultGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaOutputResult

Output result that stores the information about where the exported data is stored. Corresponds to the JSON property outputResult



4610
4611
4612
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4610

def output_result
  @output_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4617
4618
4619
4620
4621
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4617

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @output_result = args[:output_result] if args.key?(:output_result)
end