Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExportUserEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Request message for the ExportUserEvents method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaExportUserEventsRequest

Returns a new instance of GoogleCloudRetailV2betaExportUserEventsRequest.



4657
4658
4659
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

A filtering expression to specify restrictions on returned events. The expression is a sequence of terms. Each term applies a restriction to the returned user events. Use this expression to restrict results to a specific time range or to filter events by eventType. For example, eventTime > "2012- 04-23T18:25:43.511Z" eventsMissingCatalogItems eventTime<"2012-04-23T18:25:43. 511Z" eventType=search We expect only three types of fields: * eventTime: This can be specified twice, once with a less than operator and once with a greater than operator. The eventTime restriction should result in one, contiguous, valid, eventTime range. * eventType: Boolean operators OR and NOT are supported if the expression is enclosed in parentheses and the operators are separated from the tag values by a space. * eventsMissingCatalogItems: This restricts results to events for which catalog items were not found in the catalog. The default behavior is to return only those events for which catalog items were found. Some examples of valid filters expressions: * Example 1: eventTime > "2012-04-23T18:25:43.511Z" eventTime < "2012-04-23T18:30:43.511Z" * Example 2: eventTime > "2012-04- 23T18:25:43.511Z" eventType = detail-page-view * Example 3: eventsMissingCatalogItems eventType = (NOT search) eventTime < "2018-04-23T18: 30:43.511Z" * Example 4: eventTime > "2012-04-23T18:25:43.511Z" * Example 5: eventType = (detail-page-view OR search) * Example 6: eventsMissingCatalogItems Corresponds to the JSON property filter

Returns:

  • (String)


4650
4651
4652
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4650

def filter
  @filter
end

#output_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaOutputConfig

The output configuration setting. Corresponds to the JSON property outputConfig



4655
4656
4657
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4655

def output_config
  @output_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4662
4663
4664
4665
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4662

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @output_config = args[:output_config] if args.key?(:output_config)
end