Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response of the ExportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaExportUserEventsResponse

Returns a new instance of GoogleCloudRetailV2betaExportUserEventsResponse.



4671
4672
4673
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4658
4659
4660
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4658

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaExportErrorsConfig

Configuration of destination for Export related errors. Corresponds to the JSON property errorsConfig



4663
4664
4665
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4663

def errors_config
  @errors_config
end

#output_resultGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaOutputResult

Output result that stores the information about where the exported data is stored. Corresponds to the JSON property outputResult



4669
4670
4671
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4669

def output_result
  @output_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4676
4677
4678
4679
4680
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4676

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @output_result = args[:output_result] if args.key?(:output_result)
end