Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaGenerativeQuestionsFeatureConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaGenerativeQuestionsFeatureConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Configuration for overall generative question feature state.
Instance Attribute Summary collapse
-
#catalog ⇒ String
Required.
-
#feature_enabled ⇒ Boolean
(also: #feature_enabled?)
Optional.
-
#minimum_products ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaGenerativeQuestionsFeatureConfig
constructor
A new instance of GoogleCloudRetailV2betaGenerativeQuestionsFeatureConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaGenerativeQuestionsFeatureConfig
Returns a new instance of GoogleCloudRetailV2betaGenerativeQuestionsFeatureConfig.
4859 4860 4861 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4859 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog ⇒ String
Required. Resource name of the affected catalog. Format: projects/project/
locations/location/catalogs/catalog
Corresponds to the JSON property catalog
4844 4845 4846 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4844 def catalog @catalog end |
#feature_enabled ⇒ Boolean Also known as: feature_enabled?
Optional. Determines whether questions will be used at serving time. Note:
This feature cannot be enabled until initial data requirements are satisfied.
Corresponds to the JSON property featureEnabled
4850 4851 4852 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4850 def feature_enabled @feature_enabled end |
#minimum_products ⇒ Fixnum
Optional. Minimum number of products in the response to trigger follow-up
questions. Value must be 0 or positive.
Corresponds to the JSON property minimumProducts
4857 4858 4859 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4857 def minimum_products @minimum_products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4864 4865 4866 4867 4868 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4864 def update!(**args) @catalog = args[:catalog] if args.key?(:catalog) @feature_enabled = args[:feature_enabled] if args.key?(:feature_enabled) @minimum_products = args[:minimum_products] if args.key?(:minimum_products) end |