Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImportCompletionDataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response of the ImportCompletionDataRequest. If the long running operation is done, this message is returned by the google.longrunning.Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportCompletionDataResponse

Returns a new instance of GoogleCloudRetailV2betaImportCompletionDataResponse.



4983
4984
4985
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4981
4982
4983
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4981

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4988
4989
4990
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4988

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end