Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImportProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response of the ImportProductsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportProductsResponse

Returns a new instance of GoogleCloudRetailV2betaImportProductsResponse.



5144
5145
5146
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



5137
5138
5139
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5137

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



5142
5143
5144
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5142

def errors_config
  @errors_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5149
5150
5151
5152
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5149

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
end