Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaMerchantCenterLinkingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Configures Merchant Center linking. Links contained in the config will be used to sync data from a Merchant Center account to a Cloud Retail branch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaMerchantCenterLinkingConfig

Returns a new instance of GoogleCloudRetailV2betaMerchantCenterLinkingConfig.



5705
5706
5707
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Links between Merchant Center accounts and branches. Corresponds to the JSON property links



5703
5704
5705
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5703

def links
  @links
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5710
5711
5712
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5710

def update!(**args)
  @links = args[:links] if args.key?(:links)
end