Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaOutputResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Output result that stores the information about where the exported data is stored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaOutputResult

Returns a new instance of GoogleCloudRetailV2betaOutputResult.



6036
6037
6038
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_resultArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaBigQueryOutputResult>

The BigQuery location where the result is stored. Corresponds to the JSON property bigqueryResult



6029
6030
6031
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6029

def bigquery_result
  @bigquery_result
end

#gcs_resultArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaGcsOutputResult>

The Google Cloud Storage location where the result is stored. Corresponds to the JSON property gcsResult



6034
6035
6036
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6034

def gcs_result
  @gcs_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6041
6042
6043
6044
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6041

def update!(**args)
  @bigquery_result = args[:bigquery_result] if args.key?(:bigquery_result)
  @gcs_result = args[:gcs_result] if args.key?(:gcs_result)
end