Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPinControlMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Metadata for pinning to be returned in the response. This is used for distinguishing between applied vs dropped pins.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaPinControlMetadata

Returns a new instance of GoogleCloudRetailV2betaPinControlMetadata.



6108
6109
6110
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_matched_pinsHash<String,Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPinControlMetadataProductPins>

Map of all matched pins, keyed by pin position. Corresponds to the JSON property allMatchedPins



6100
6101
6102
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6100

def all_matched_pins
  @all_matched_pins
end

#dropped_pinsHash<String,Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPinControlMetadataProductPins>

Map of pins that were dropped due to overlap with other matching pins, keyed by pin position. Corresponds to the JSON property droppedPins



6106
6107
6108
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6106

def dropped_pins
  @dropped_pins
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6113
6114
6115
6116
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6113

def update!(**args)
  @all_matched_pins = args[:all_matched_pins] if args.key?(:all_matched_pins)
  @dropped_pins = args[:dropped_pins] if args.key?(:dropped_pins)
end