Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPredictResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPredictResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Response message for predict method.
Instance Attribute Summary collapse
-
#attribution_token ⇒ String
A unique attribution token.
-
#missing_ids ⇒ Array<String>
IDs of products in the request that were missing from the inventory.
-
#results ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPredictResponsePredictionResult>
A list of recommended products.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
True if the validateOnly property was set in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaPredictResponse
constructor
A new instance of GoogleCloudRetailV2betaPredictResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaPredictResponse
Returns a new instance of GoogleCloudRetailV2betaPredictResponse.
6278 6279 6280 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_token ⇒ String
A unique attribution token. This should be included in the UserEvent logs
resulting from this recommendation, which enables accurate attribution of
recommendation model performance.
Corresponds to the JSON property attributionToken
6259 6260 6261 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6259 def attribution_token @attribution_token end |
#missing_ids ⇒ Array<String>
IDs of products in the request that were missing from the inventory.
Corresponds to the JSON property missingIds
6264 6265 6266 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6264 def missing_ids @missing_ids end |
#results ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPredictResponsePredictionResult>
A list of recommended products. The order represents the ranking (from the
most relevant product to the least).
Corresponds to the JSON property results
6270 6271 6272 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6270 def results @results end |
#validate_only ⇒ Boolean Also known as: validate_only?
True if the validateOnly property was set in the request.
Corresponds to the JSON property validateOnly
6275 6276 6277 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6275 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6283 6284 6285 6286 6287 6288 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6283 def update!(**args) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @missing_ids = args[:missing_ids] if args.key?(:missing_ids) @results = args[:results] if args.key?(:results) @validate_only = args[:validate_only] if args.key?(:validate_only) end |