Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProduct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Product captures all metadata information of items to be recommended or searched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaProduct

Returns a new instance of GoogleCloudRetailV2betaProduct.



6769
6770
6771
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCustomAttribute>

Highly encouraged. Extra product attributes to be included. For example, for products, this could include the store name, vendor, style, color, etc. These are very strong signals for recommendation model, thus we highly recommend providing the attributes here. Features that can take on one of a limited number of possible values. Two types of features can be set are: Textual features. some examples would be the brand/maker of a product, or country of a customer. Numerical features. Some examples would be the height/weight of a product, or age of a customer. For example: "vendor": `"text": ["vendor123", "vendor456"]`, "lengths_cm": `"numbers":[2.3, 15.4]`, "heights_cm": `"numbers" :[8.1, 6.4]`. This field needs to pass all below criteria, otherwise an INVALID_ARGUMENT error is returned: * Max entries count: 200. * The key must be a UTF-8 encoded string with a length limit of 128 characters. * For indexable attribute, the key must match the pattern: a-zA-Z0-9*. For example, key0LikeThis or KEY_1_LIKE_THIS. * For text attributes, at most 400 values are allowed. Empty values are not allowed. Each value must be a non- empty UTF-8 encoded string with a length limit of 256 characters. * For number attributes, at most 400 values are allowed. Corresponds to the JSON property attributes



6442
6443
6444
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6442

def attributes
  @attributes
end

#audienceGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaAudience

An intended audience of the Product for whom it's sold. Corresponds to the JSON property audience



6447
6448
6449
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6447

def audience
  @audience
end

#availabilityString

The online availability of the Product. Default to Availability.IN_STOCK. For primary products with variants set the availability of the primary as Availability.OUT_OF_STOCK and set the true availability at the variant level. This way the primary product will be considered "in stock" as long as it has at least one variant in stock. For primary products with no variants set the true availability at the primary level. Corresponding properties: Google Merchant Center property availability. Schema.org property Offer.availability. Corresponds to the JSON property availability

Returns:

  • (String)


6460
6461
6462
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6460

def availability
  @availability
end

#available_quantityFixnum

The available quantity of the item. Corresponds to the JSON property availableQuantity

Returns:

  • (Fixnum)


6465
6466
6467
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6465

def available_quantity
  @available_quantity
end

#available_timeString

The timestamp when this Product becomes available for SearchService.Search. Note that this is only applicable to Type.PRIMARY and Type.COLLECTION, and ignored for Type.VARIANT. Corresponds to the JSON property availableTime

Returns:

  • (String)


6472
6473
6474
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6472

def available_time
  @available_time
end

#brandsArray<String>

The brands of the product. A maximum of 30 brands are allowed unless overridden through the Google Cloud console. Each brand must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property brand. Schema.org property Product.brand. Corresponds to the JSON property brands

Returns:

  • (Array<String>)


6482
6483
6484
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6482

def brands
  @brands
end

#categoriesArray<String>

Optional. Product categories. This field is repeated for supporting one product belonging to several parallel categories. Strongly recommended using the full path for better search / recommendation quality. To represent the full path of category, use the '>' sign, with one space on each side, to separate different hierarchies. If '>' is part of the category name, replace it with other character(s). For example, if a shoes product belongs to both [" Shoes & Accessories" -> "Shoes"] and ["Sports & Fitness" -> "Athletic Clothing" -> "Shoes"], it could be represented as: "categories": [ "Shoes & Accessories

Shoes", "Sports & Fitness > Athletic Clothing > Shoes" ] Must be set for Type.PRIMARY Product otherwise an INVALID_ARGUMENT error is returned. At most 250 values are allowed per Product unless overridden through the Google Cloud console. Empty values are not allowed. Each value must be a UTF-8 encoded string with a length limit of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property google_product_category. Schema.org property Product.category. [mc_google_product_category]: https://support.google.com/ merchants/answer/6324436 Corresponds to the JSON property categories

Returns:

  • (Array<String>)


6503
6504
6505
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6503

def categories
  @categories
end

#collection_member_idsArray<String>

The id of the collection members when type is Type.COLLECTION. Non-existent product ids are allowed. The type of the members must be either Type.PRIMARY or Type.VARIANT otherwise an INVALID_ARGUMENT error is thrown. Should not set it for other types. A maximum of 1000 values are allowed. Otherwise, an INVALID_ARGUMENT error is return. Corresponds to the JSON property collectionMemberIds

Returns:

  • (Array<String>)


6512
6513
6514
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6512

def collection_member_ids
  @collection_member_ids
end

#color_infoGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaColorInfo

The color information of a Product. Corresponds to the JSON property colorInfo



6517
6518
6519
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6517

def color_info
  @color_info
end

#conditionsArray<String>

The condition of the product. Strongly encouraged to use the standard values: " new", "refurbished", "used". A maximum of 1 value is allowed per Product. Each value must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property condition. Schema.org property Offer.itemCondition. Corresponds to the JSON property conditions

Returns:

  • (Array<String>)


6528
6529
6530
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6528

def conditions
  @conditions
end

#descriptionString

Product description. This field must be a UTF-8 encoded string with a length limit of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property description. Schema.org property Product. description. Corresponds to the JSON property description

Returns:

  • (String)


6537
6538
6539
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6537

def description
  @description
end

#expire_timeString

Note that this field is applied in the following ways: * If the Product is already expired when it is uploaded, this product is not indexed for search. * If the Product is not expired when it is uploaded, only the Type.PRIMARY's and Type.COLLECTION's expireTime is respected, and Type.VARIANT's expireTime is not used. In general, we suggest the users to delete the stale products explicitly, instead of using this field to determine staleness. expire_time must be later than available_time and publish_time, otherwise an INVALID_ARGUMENT error is thrown. Corresponding properties: Google Merchant Center property expiration_date. Corresponds to the JSON property expireTime

Returns:

  • (String)


6551
6552
6553
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6551

def expire_time
  @expire_time
end

#fulfillment_infoArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaFulfillmentInfo>

Fulfillment information, such as the store IDs for in-store pickup or region IDs for different shipping methods. All the elements must have distinct FulfillmentInfo.type. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property fulfillmentInfo



6558
6559
6560
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6558

def fulfillment_info
  @fulfillment_info
end

#gtinString

The Global Trade Item Number (GTIN) of the product. This field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. This field must be a Unigram. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property gtin. Schema.org property Product.isbn, Product.gtin8, Product.gtin12, Product.gtin13, or Product.gtin14. If the value is not a valid GTIN, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property gtin

Returns:

  • (String)


6572
6573
6574
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6572

def gtin
  @gtin
end

#idString

Immutable. Product identifier, which is the final component of name. For example, this field is "id_1", if name is projects/*/locations/global/ catalogs/default_catalog/branches/default_branch/products/id_1. This field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property id. Schema.org property Product.sku. Corresponds to the JSON property id

Returns:

  • (String)


6583
6584
6585
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6583

def id
  @id
end

#imagesArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImage>

Product images for the product. We highly recommend putting the main image first. A maximum of 300 images are allowed. Corresponding properties: Google Merchant Center property image_link. Schema.org property Product.image. Corresponds to the JSON property images



6591
6592
6593
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6591

def images
  @images
end

#language_codeString

Language of the title/description and other string attributes. Use language tags defined by BCP 47. For product prediction, this field is ignored and the model automatically detects the text language. The Product can include text in different languages, but duplicating Products to provide text in multiple languages can result in degraded model performance. For product search this field is in use. It defaults to "en-US" if unset. Corresponds to the JSON property languageCode

Returns:

  • (String)


6602
6603
6604
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6602

def language_code
  @language_code
end

#local_inventoriesArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaLocalInventory>

Output only. A list of local inventories specific to different places. This field can be managed by ProductService.AddLocalInventories and ProductService. RemoveLocalInventories APIs if fine-grained, high-volume updates are necessary. Corresponds to the JSON property localInventories



6609
6610
6611
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6609

def local_inventories
  @local_inventories
end

#materialsArray<String>

The material of the product. For example, "leather", "wooden". A maximum of 20 values are allowed. Each value must be a UTF-8 encoded string with a length limit of 200 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property material. Schema.org property Product. material. Corresponds to the JSON property materials

Returns:

  • (Array<String>)


6619
6620
6621
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6619

def materials
  @materials
end

#nameString

Immutable. Full resource name of the product, such as projects/*/locations/ global/catalogs/default_catalog/branches/default_branch/products/product_id. Corresponds to the JSON property name

Returns:

  • (String)


6625
6626
6627
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6625

def name
  @name
end

#patternsArray<String>

The pattern or graphic print of the product. For example, "striped", "polka dot", "paisley". A maximum of 20 values are allowed per Product. Each value must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property pattern. Schema.org property Product.pattern. Corresponds to the JSON property patterns

Returns:

  • (Array<String>)


6636
6637
6638
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6636

def patterns
  @patterns
end

#price_infoGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaPriceInfo

The price information of a Product. Corresponds to the JSON property priceInfo



6641
6642
6643
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6641

def price_info
  @price_info
end

#primary_product_idString

Variant group identifier. Must be an id, with the same parent branch with this product. Otherwise, an error is thrown. For Type.PRIMARY Products, this field can only be empty or set to the same value as id. For VARIANT Products, this field cannot be empty. A maximum of 2,000 products are allowed to share the same Type.PRIMARY Product. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property item_group_id. Schema.org property Product.inProductGroupWithID. Corresponds to the JSON property primaryProductId

Returns:

  • (String)


6653
6654
6655
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6653

def primary_product_id
  @primary_product_id
end

#promotionsArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPromotion>

The promotions applied to the product. A maximum of 10 values are allowed per Product. Only Promotion.promotion_id will be used, other fields will be ignored if set. Corresponds to the JSON property promotions



6660
6661
6662
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6660

def promotions
  @promotions
end

#publish_timeString

The timestamp when the product is published by the retailer for the first time, which indicates the freshness of the products. Note that this field is different from available_time, given it purely describes product freshness regardless of when it is available on search and recommendation. Corresponds to the JSON property publishTime

Returns:

  • (String)


6668
6669
6670
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6668

def publish_time
  @publish_time
end

#ratingGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaRating

The rating of a Product. Corresponds to the JSON property rating



6673
6674
6675
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6673

def rating
  @rating
end

#retrievable_fieldsString

Indicates which fields in the Products are returned in SearchResponse. Supported fields for all types: * audience * availability * brands * color_info * conditions * gtin * materials * name * patterns * price_info * rating * sizes * title * uri Supported fields only for Type.PRIMARY and Type. COLLECTION: * categories * description * images Supported fields only for Type. VARIANT: * Only the first image in images To mark attributes as retrievable, include paths of the form "attributes.key" where "key" is the key of a custom attribute, as specified in attributes. For Type.PRIMARY and Type.COLLECTION, the following fields are always returned in SearchResponse by default: * name For Type.VARIANT, the following fields are always returned in by default: * name * color_info Note: Returning more fields in SearchResponse can increase response payload size and serving latency. This field is deprecated. Use the retrievable site-wide control instead. Corresponds to the JSON property retrievableFields

Returns:

  • (String)


6690
6691
6692
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6690

def retrievable_fields
  @retrievable_fields
end

#sizesArray<String>

The size of the product. To represent different size systems or size types, consider using this format: [[[size_system:]size_type:]size_value]. For example, in "US:MENS:M", "US" represents size system; "MENS" represents size type; "M" represents size value. In "GIRLS:27", size system is empty; "GIRLS" represents size type; "27" represents size value. In "32 inches", both size system and size type are empty, while size value is "32 inches". A maximum of 20 values are allowed per Product. Each value must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property size, size_type, and size_system. Schema.org property Product. size. Corresponds to the JSON property sizes

Returns:

  • (Array<String>)


6707
6708
6709
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6707

def sizes
  @sizes
end

#tagsArray<String>

Custom tags associated with the product. At most 250 values are allowed per Product. This value must be a UTF-8 encoded string with a length limit of 1, 000 characters. Otherwise, an INVALID_ARGUMENT error is returned. This tag can be used for filtering recommendation results by passing the tag as part of the PredictRequest.filter. Corresponding properties: Google Merchant Center property custom_label_0–4. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


6718
6719
6720
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6718

def tags
  @tags
end

#titleString

Required. Product title. This field must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property title. Schema.org property Product.name. Corresponds to the JSON property title

Returns:

  • (String)


6727
6728
6729
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6727

def title
  @title
end

#ttlString

Input only. The TTL (time to live) of the product. Note that this is only applicable to Type.PRIMARY and Type.COLLECTION, and ignored for Type.VARIANT. In general, we suggest the users to delete the stale products explicitly, instead of using this field to determine staleness. If it is set, it must be a non-negative value, and expire_time is set as current timestamp plus ttl. The derived expire_time is returned in the output and ttl is left blank when retrieving the Product. If it is set, the product is not available for SearchService.Search after current timestamp plus ttl. However, the product can still be retrieved by ProductService.GetProduct and ProductService. ListProducts. Corresponds to the JSON property ttl

Returns:

  • (String)


6741
6742
6743
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6741

def ttl
  @ttl
end

#typeString

Immutable. The type of the product. Default to Catalog.product_level_config. ingestion_product_type if unset. Corresponds to the JSON property type

Returns:

  • (String)


6747
6748
6749
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6747

def type
  @type
end

#uriString

Canonical URL directly linking to the product detail page. It is strongly recommended to provide a valid uri for the product, otherwise the service performance could be significantly degraded. This field must be a UTF-8 encoded string with a length limit of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponding properties: Google Merchant Center property link. Schema.org property Offer.url. Corresponds to the JSON property uri

Returns:

  • (String)


6758
6759
6760
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6758

def uri
  @uri
end

#variantsArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProduct>

Output only. Product variants grouped together on primary product which share similar product attributes. It's automatically grouped by primary_product_id for all the product variants. Only populated for Type.PRIMARY Products. Note: This field is OUTPUT_ONLY for ProductService.GetProduct. Do not set this field in API requests. Corresponds to the JSON property variants



6767
6768
6769
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6767

def variants
  @variants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6774
6775
6776
6777
6778
6779
6780
6781
6782
6783
6784
6785
6786
6787
6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
6808
6809
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6774

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @audience = args[:audience] if args.key?(:audience)
  @availability = args[:availability] if args.key?(:availability)
  @available_quantity = args[:available_quantity] if args.key?(:available_quantity)
  @available_time = args[:available_time] if args.key?(:available_time)
  @brands = args[:brands] if args.key?(:brands)
  @categories = args[:categories] if args.key?(:categories)
  @collection_member_ids = args[:collection_member_ids] if args.key?(:collection_member_ids)
  @color_info = args[:color_info] if args.key?(:color_info)
  @conditions = args[:conditions] if args.key?(:conditions)
  @description = args[:description] if args.key?(:description)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @fulfillment_info = args[:fulfillment_info] if args.key?(:fulfillment_info)
  @gtin = args[:gtin] if args.key?(:gtin)
  @id = args[:id] if args.key?(:id)
  @images = args[:images] if args.key?(:images)
  @language_code = args[:language_code] if args.key?(:language_code)
  @local_inventories = args[:local_inventories] if args.key?(:local_inventories)
  @materials = args[:materials] if args.key?(:materials)
  @name = args[:name] if args.key?(:name)
  @patterns = args[:patterns] if args.key?(:patterns)
  @price_info = args[:price_info] if args.key?(:price_info)
  @primary_product_id = args[:primary_product_id] if args.key?(:primary_product_id)
  @promotions = args[:promotions] if args.key?(:promotions)
  @publish_time = args[:publish_time] if args.key?(:publish_time)
  @rating = args[:rating] if args.key?(:rating)
  @retrievable_fields = args[:retrievable_fields] if args.key?(:retrievable_fields)
  @sizes = args[:sizes] if args.key?(:sizes)
  @tags = args[:tags] if args.key?(:tags)
  @title = args[:title] if args.key?(:title)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @uri = args[:uri] if args.key?(:uri)
  @variants = args[:variants] if args.key?(:variants)
end