Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeValue
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Product attribute which structured by an attribute name and value. This
structure is used in conversational search filters and answers. For example,
if we have name=color and value=red, this means that the color is red.
Instance Attribute Summary collapse
-
#name ⇒ String
The attribute name.
-
#value ⇒ String
The attribute value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaProductAttributeValue
constructor
A new instance of GoogleCloudRetailV2betaProductAttributeValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaProductAttributeValue
Returns a new instance of GoogleCloudRetailV2betaProductAttributeValue.
6872 6873 6874 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The attribute name.
Corresponds to the JSON property name
6865 6866 6867 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6865 def name @name end |
#value ⇒ String
The attribute value.
Corresponds to the JSON property value
6870 6871 6872 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6870 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6877 6878 6879 6880 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6877 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |