Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurchaseTransaction
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurchaseTransaction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
A transaction represents the entire purchase transaction.
Instance Attribute Summary collapse
-
#cost ⇒ Float
All the costs associated with the products.
-
#currency_code ⇒ String
Required.
-
#id ⇒ String
The transaction ID with a length limit of 128 characters.
-
#revenue ⇒ Float
Required.
-
#tax ⇒ Float
All the taxes associated with the transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaPurchaseTransaction
constructor
A new instance of GoogleCloudRetailV2betaPurchaseTransaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaPurchaseTransaction
Returns a new instance of GoogleCloudRetailV2betaPurchaseTransaction.
7047 7048 7049 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cost ⇒ Float
All the costs associated with the products. These can be manufacturing costs,
shipping expenses not borne by the end user, or any other costs, such that: *
Profit = revenue - tax - cost
Corresponds to the JSON property cost
7023 7024 7025 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7023 def cost @cost end |
#currency_code ⇒ String
Required. Currency code. Use three-character ISO-4217 code.
Corresponds to the JSON property currencyCode
7028 7029 7030 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7028 def currency_code @currency_code end |
#id ⇒ String
The transaction ID with a length limit of 128 characters.
Corresponds to the JSON property id
7033 7034 7035 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7033 def id @id end |
#revenue ⇒ Float
Required. Total non-zero revenue or grand total associated with the
transaction. This value include shipping, tax, or other adjustments to total
revenue that you want to include as part of your revenue calculations.
Corresponds to the JSON property revenue
7040 7041 7042 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7040 def revenue @revenue end |
#tax ⇒ Float
All the taxes associated with the transaction.
Corresponds to the JSON property tax
7045 7046 7047 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7045 def tax @tax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7052 7053 7054 7055 7056 7057 7058 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7052 def update!(**args) @cost = args[:cost] if args.key?(:cost) @currency_code = args[:currency_code] if args.key?(:currency_code) @id = args[:id] if args.key?(:id) @revenue = args[:revenue] if args.key?(:revenue) @tax = args[:tax] if args.key?(:tax) end |