Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurgeProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response of the PurgeProductsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning. Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaPurgeProductsResponse

Returns a new instance of GoogleCloudRetailV2betaPurgeProductsResponse.



7191
7192
7193
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The total count of products purged as a result of the operation. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


7182
7183
7184
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7182

def purge_count
  @purge_count
end

#purge_sampleArray<String>

A sample of the product names that will be deleted. Only populated if force is set to false. A max of 100 names will be returned and the names are chosen at random. Corresponds to the JSON property purgeSample

Returns:

  • (Array<String>)


7189
7190
7191
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7189

def purge_sample
  @purge_sample
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7196
7197
7198
7199
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7196

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
  @purge_sample = args[:purge_sample] if args.key?(:purge_sample)
end