Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaRuleBoostAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

A boost action to apply to results matching condition specified above.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaRuleBoostAction

Returns a new instance of GoogleCloudRetailV2betaRuleBoostAction.



7750
7751
7752
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Strength of the condition boost, which must be in [-1, 1]. Negative boost means demotion. Default is 0.0. Setting to 1.0 gives the item a big promotion. However, it does not necessarily mean that the boosted item will be the top result at all times, nor that other items will be excluded. Results could still be shown even when none of them matches the condition. And results that are significantly more relevant to the search query can still trump your heavily favored but irrelevant items. Setting to -1.0 gives the item a big demotion. However, results that are deeply relevant might still be shown. The item will have an upstream battle to get a fairly high ranking, but it is not blocked out completely. Setting to 0.0 means no boost applied. The boosting condition is ignored. Corresponds to the JSON property boost

Returns:

  • (Float)


7738
7739
7740
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7738

def boost
  @boost
end

#products_filterString

The filter can have a max size of 5000 characters. An expression which specifies which products to apply an action to. The syntax and supported fields are the same as a filter expression. See SearchRequest.filter for detail syntax and limitations. Examples: * To boost products with product ID " product_1" or "product_2", and color "Red" or "Blue": *(id: ANY("product_1", " product_2")) * *AND * *(colorFamilies: ANY("Red", "Blue")) * Corresponds to the JSON property productsFilter

Returns:

  • (String)


7748
7749
7750
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7748

def products_filter
  @products_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7755
7756
7757
7758
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7755

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @products_filter = args[:products_filter] if args.key?(:products_filter)
end