Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaRuleFilterAction
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaRuleFilterAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
- Rule Condition: - No Condition.query_terms provided is a global match. - 1 or more Condition.query_terms provided are combined with OR operator. * Action Input: The request query and filter that are applied to the retrieved products, in addition to any filters already provided with the SearchRequest. The AND operator is used to combine the query's existing filters with the filter rule( s). NOTE: May result in 0 results when filters conflict. * Action Result: Filters the returned objects to be ONLY those that passed the filter.
Instance Attribute Summary collapse
-
#filter ⇒ String
A filter to apply on the matching condition results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaRuleFilterAction
constructor
A new instance of GoogleCloudRetailV2betaRuleFilterAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaRuleFilterAction
Returns a new instance of GoogleCloudRetailV2betaRuleFilterAction.
7814 7815 7816 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7814 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
A filter to apply on the matching condition results. Supported features: *
filter must be set. * Filter syntax is identical to SearchRequest.filter. For
more information, see Filter. * To
filter products with product ID "product_1" or "product_2", and color "Red" or
"Blue": *(id: ANY("product_1", "product_2")) * *AND * *(colorFamilies: ANY("
Red", "Blue")) *
Corresponds to the JSON property filter
7812 7813 7814 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7812 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7819 7820 7821 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7819 def update!(**args) @filter = args[:filter] if args.key?(:filter) end |