Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestFacetSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

A facet specification to perform faceted search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchRequestFacetSpec

Returns a new instance of GoogleCloudRetailV2betaSearchRequestFacetSpec.



8626
8627
8628
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_dynamic_positionBoolean Also known as: enable_dynamic_position?

Enables dynamic position for this facet. If set to true, the position of this facet among all facets in the response is determined by Google Retail Search. It is ordered together with dynamic facets if dynamic facets is enabled. If set to false, the position of this facet in the response is the same as in the request, and it is ranked before the facets with dynamic position enable and all dynamic facets. For example, you may always want to have rating facet returned in the response, but it's not necessarily to always display the rating facet at the top. In that case, you can set enable_dynamic_position to true so that the position of rating facet in response is determined by Google Retail Search. Another example, assuming you have the following facets in the request: * "rating", enable_dynamic_position = true * "price", enable_dynamic_position = false * "brands", enable_dynamic_position = false And also you have a dynamic facets enable, which generates a facet "gender". Then, the final order of the facets in the response can be ("price", "brands", "rating", "gender") or ("price", "brands", "gender", "rating") depends on how Google Retail Search orders "gender" and "rating" facets. However, notice that "price" and "brands" are always ranked at first and second position because their enable_dynamic_position values are false. Corresponds to the JSON property enableDynamicPosition

Returns:

  • (Boolean)


8591
8592
8593
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8591

def enable_dynamic_position
  @enable_dynamic_position
end

#excluded_filter_keysArray<String>

List of keys to exclude when faceting. By default, FacetKey.key is not excluded from the filter unless it is listed in this field. Listing a facet key in this field allows its values to appear as facet results, even when they are filtered out of search results. Using this field does not affect what search results are returned. For example, suppose there are 100 products with the color facet "Red" and 200 products with the color facet "Blue". A query containing the filter "colorFamilies:ANY("Red")" and having "colorFamilies" as FacetKey.key would by default return only "Red" products in the search results, and also return "Red" with count 100 as the only color facet. Although there are also blue products available, "Blue" would not be shown as an available facet value. If "colorFamilies" is listed in "excludedFilterKeys", then the query returns the facet values "Red" with count 100 and "Blue" with count 200, because the "colorFamilies" key is now excluded from the filter. Because this field doesn't affect search results, the search results are still correctly filtered to return only "Red" products. A maximum of 100 values are allowed. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property excludedFilterKeys

Returns:

  • (Array<String>)


8612
8613
8614
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8612

def excluded_filter_keys
  @excluded_filter_keys
end

#facet_keyGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestFacetSpecFacetKey

Specifies how a facet is computed. Corresponds to the JSON property facetKey



8617
8618
8619
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8617

def facet_key
  @facet_key
end

#limitFixnum

Maximum of facet values that should be returned for this facet. If unspecified, defaults to 50. The maximum allowed value is 300. Values above 300 will be coerced to 300. If this field is negative, an INVALID_ARGUMENT is returned. Corresponds to the JSON property limit

Returns:

  • (Fixnum)


8624
8625
8626
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8624

def limit
  @limit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8631
8632
8633
8634
8635
8636
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8631

def update!(**args)
  @enable_dynamic_position = args[:enable_dynamic_position] if args.key?(:enable_dynamic_position)
  @excluded_filter_keys = args[:excluded_filter_keys] if args.key?(:excluded_filter_keys)
  @facet_key = args[:facet_key] if args.key?(:facet_key)
  @limit = args[:limit] if args.key?(:limit)
end