Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseFacetFacetValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

A facet value which contains value names and their count.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchResponseFacetFacetValue

Returns a new instance of GoogleCloudRetailV2betaSearchResponseFacetFacetValue.



9120
9121
9122
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Number of items that have this facet value. Corresponds to the JSON property count

Returns:

  • (Fixnum)


9096
9097
9098
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9096

def count
  @count
end

#intervalGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaInterval

A floating point interval. Corresponds to the JSON property interval



9101
9102
9103
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9101

def interval
  @interval
end

#max_valueFloat

The maximum value in the FacetValue.interval. Only supported on numerical facets and returned if SearchRequest.FacetSpec.FacetKey.return_min_max is true. Corresponds to the JSON property maxValue

Returns:

  • (Float)


9107
9108
9109
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9107

def max_value
  @max_value
end

#min_valueFloat

The minimum value in the FacetValue.interval. Only supported on numerical facets and returned if SearchRequest.FacetSpec.FacetKey.return_min_max is true. Corresponds to the JSON property minValue

Returns:

  • (Float)


9113
9114
9115
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9113

def min_value
  @min_value
end

#valueString

Text value of a facet, such as "Black" for facet "colorFamilies". Corresponds to the JSON property value

Returns:

  • (String)


9118
9119
9120
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9118

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9125
9126
9127
9128
9129
9130
9131
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9125

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @interval = args[:interval] if args.key?(:interval)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
  @value = args[:value] if args.key?(:value)
end