Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseTileNavigationResult
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseTileNavigationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
This field specifies all related information for tile navigation that will be used in client side.
Instance Attribute Summary collapse
-
#tiles ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaTile>
The current tiles that are used for tile navigation, sorted by engagement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchResponseTileNavigationResult
constructor
A new instance of GoogleCloudRetailV2betaSearchResponseTileNavigationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchResponseTileNavigationResult
Returns a new instance of GoogleCloudRetailV2betaSearchResponseTileNavigationResult.
9264 9265 9266 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tiles ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaTile>
The current tiles that are used for tile navigation, sorted by engagement.
Corresponds to the JSON property tiles
9262 9263 9264 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9262 def tiles @tiles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9269 9270 9271 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9269 def update!(**args) @tiles = args[:tiles] if args.key?(:tiles) end |