Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaTile
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaTile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
This field specifies the tile information including an attribute key, attribute value. More fields will be added in the future, eg: product id or product counts, etc.
Instance Attribute Summary collapse
-
#product_attribute_interval ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeInterval
Product attribute name and numeric interval.
-
#product_attribute_value ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeValue
Product attribute which structured by an attribute name and value.
-
#representative_product_id ⇒ String
The representative product id for this tile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaTile
constructor
A new instance of GoogleCloudRetailV2betaTile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaTile
Returns a new instance of GoogleCloudRetailV2betaTile.
9610 9611 9612 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9610 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_attribute_interval ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeInterval
Product attribute name and numeric interval.
Corresponds to the JSON property productAttributeInterval
9596 9597 9598 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9596 def product_attribute_interval @product_attribute_interval end |
#product_attribute_value ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeValue
Product attribute which structured by an attribute name and value. This
structure is used in conversational search filters and answers. For example,
if we have name=color and value=red, this means that the color is red.
Corresponds to the JSON property productAttributeValue
9603 9604 9605 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9603 def product_attribute_value @product_attribute_value end |
#representative_product_id ⇒ String
The representative product id for this tile.
Corresponds to the JSON property representativeProductId
9608 9609 9610 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9608 def representative_product_id @representative_product_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9615 9616 9617 9618 9619 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9615 def update!(**args) @product_attribute_interval = args[:product_attribute_interval] if args.key?(:product_attribute_interval) @product_attribute_value = args[:product_attribute_value] if args.key?(:product_attribute_value) @representative_product_id = args[:representative_product_id] if args.key?(:representative_product_id) end |