Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaUserEventInputConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaUserEventInputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
The input config source for user events.
Instance Attribute Summary collapse
-
#big_query_source ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaBigQuerySource
BigQuery source import data from.
-
#gcs_source ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaGcsSource
Google Cloud Storage location for input content.
-
#user_event_inline_source ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaUserEventInlineSource
The inline source for the input config for ImportUserEvents method.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaUserEventInputConfig
constructor
A new instance of GoogleCloudRetailV2betaUserEventInputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaUserEventInputConfig
Returns a new instance of GoogleCloudRetailV2betaUserEventInputConfig.
10020 10021 10022 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_source ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaBigQuerySource
BigQuery source import data from.
Corresponds to the JSON property bigQuerySource
10008 10009 10010 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10008 def big_query_source @big_query_source end |
#gcs_source ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaGcsSource
Google Cloud Storage location for input content.
Corresponds to the JSON property gcsSource
10013 10014 10015 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10013 def gcs_source @gcs_source end |
#user_event_inline_source ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaUserEventInlineSource
The inline source for the input config for ImportUserEvents method.
Corresponds to the JSON property userEventInlineSource
10018 10019 10020 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10018 def user_event_inline_source @user_event_inline_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10025 10026 10027 10028 10029 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10025 def update!(**args) @big_query_source = args[:big_query_source] if args.key?(:big_query_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @user_event_inline_source = args[:user_event_inline_source] if args.key?(:user_event_inline_source) end |