Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaUserInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Information of an end user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaUserInfo

Returns a new instance of GoogleCloudRetailV2betaUserInfo.



10060
10061
10062
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#direct_user_requestBoolean Also known as: direct_user_request?

True if the request is made directly from the end user, in which case the ip_address and user_agent can be populated from the HTTP request. This flag should be set only if the API request is made directly from the end user such as a mobile app (and not if a gateway or a server is processing and pushing the user events). This should not be set when using the JavaScript tag in UserEventService.CollectUserEvent. Corresponds to the JSON property directUserRequest

Returns:

  • (Boolean)


10028
10029
10030
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10028

def direct_user_request
  @direct_user_request
end

#ip_addressString

The end user's IP address. This field is used to extract location information for personalization. This field must be either an IPv4 address (e.g. "104.133. 9.80") or an IPv6 address (e.g. "2001:0db8:85a3:0000:0000:8a2e:0370:7334"). Otherwise, an INVALID_ARGUMENT error is returned. This should not be set when:

  • setting SearchRequest.user_info. * using the JavaScript tag in UserEventService.CollectUserEvent or if direct_user_request is set. Corresponds to the JSON property ipAddress

Returns:

  • (String)


10039
10040
10041
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10039

def ip_address
  @ip_address
end

#user_agentString

User agent as included in the HTTP header. The field must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. This should not be set when using the client side event reporting with GTM or JavaScript tag in UserEventService.CollectUserEvent or if direct_user_request is set. Corresponds to the JSON property userAgent

Returns:

  • (String)


10048
10049
10050
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10048

def user_agent
  @user_agent
end

#user_idString

Highly recommended for logged-in users. Unique identifier for logged-in user, such as a user name. Don't set for anonymous users. Always use a hashed value for this ID. Don't set the field to the same fixed ID for different users. This mixes the event history of those users together, which results in degraded model quality. The field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property userId

Returns:

  • (String)


10058
10059
10060
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10058

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10065
10066
10067
10068
10069
10070
# File 'lib/google/apis/retail_v2beta/classes.rb', line 10065

def update!(**args)
  @direct_user_request = args[:direct_user_request] if args.key?(:direct_user_request)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @user_id = args[:user_id] if args.key?(:user_id)
end