Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCatalog
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCatalog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
The catalog configuration.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#merchant_center_linking_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaMerchantCenterLinkingConfig
Configures Merchant Center linking.
-
#name ⇒ String
Required.
-
#product_level_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductLevelConfig
Configures what level the product should be uploaded with regards to how users will be send events and how predictions will be made.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaCatalog
constructor
A new instance of GoogleCloudRetailV2betaCatalog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaCatalog
Returns a new instance of GoogleCloudRetailV2betaCatalog.
3009 3010 3011 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. Immutable. The catalog display name. This field must be a UTF-8
encoded string with a length limit of 128 characters. Otherwise, an
INVALID_ARGUMENT error is returned.
Corresponds to the JSON property displayName
2990 2991 2992 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2990 def display_name @display_name end |
#merchant_center_linking_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaMerchantCenterLinkingConfig
Configures Merchant Center linking. Links contained in the config will be used
to sync data from a Merchant Center account to a Cloud Retail branch.
Corresponds to the JSON property merchantCenterLinkingConfig
2996 2997 2998 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 2996 def merchant_center_linking_config @merchant_center_linking_config end |
#name ⇒ String
Required. Immutable. The fully qualified resource name of the catalog.
Corresponds to the JSON property name
3001 3002 3003 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3001 def name @name end |
#product_level_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductLevelConfig
Configures what level the product should be uploaded with regards to how users
will be send events and how predictions will be made.
Corresponds to the JSON property productLevelConfig
3007 3008 3009 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3007 def product_level_config @product_level_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3014 3015 3016 3017 3018 3019 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3014 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @merchant_center_linking_config = args[:merchant_center_linking_config] if args.key?(:merchant_center_linking_config) @name = args[:name] if args.key?(:name) @product_level_config = args[:product_level_config] if args.key?(:product_level_config) end |