Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchCustomizationConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchCustomizationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
The public proto to represent the conversational search customization config. It will be converted to the internal proto in the backend.
Instance Attribute Summary collapse
-
#catalog ⇒ String
Required.
-
#intent_classification_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaIntentClassificationConfig
The public proto to represent the intent classification config.
-
#retailer_display_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaConversationalSearchCustomizationConfig
constructor
A new instance of GoogleCloudRetailV2betaConversationalSearchCustomizationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaConversationalSearchCustomizationConfig
Returns a new instance of GoogleCloudRetailV2betaConversationalSearchCustomizationConfig.
3876 3877 3878 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog ⇒ String
Required. Resource name of the catalog. Format: projects/project/locations/
location/catalogs/catalog
Corresponds to the JSON property catalog
3862 3863 3864 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3862 def catalog @catalog end |
#intent_classification_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaIntentClassificationConfig
The public proto to represent the intent classification config. It will be
converted to the internal proto in the backend.
Corresponds to the JSON property intentClassificationConfig
3868 3869 3870 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3868 def intent_classification_config @intent_classification_config end |
#retailer_display_name ⇒ String
Optional. The retailer's display name that could be used in our LLM answers.
Example - "Google"
Corresponds to the JSON property retailerDisplayName
3874 3875 3876 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3874 def retailer_display_name @retailer_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3881 3882 3883 3884 3885 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 3881 def update!(**args) @catalog = args[:catalog] if args.key?(:catalog) @intent_classification_config = args[:intent_classification_config] if args.key?(:intent_classification_config) @retailer_display_name = args[:retailer_display_name] if args.key?(:retailer_display_name) end |