Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchRequestSearchParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Search parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaConversationalSearchRequestSearchParams

Returns a new instance of GoogleCloudRetailV2betaConversationalSearchRequestSearchParams.



4053
4054
4055
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestBoostSpec

Boost specification to boost certain items. Corresponds to the JSON property boostSpec



4033
4034
4035
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4033

def boost_spec
  @boost_spec
end

#canonical_filterString

Optional. The canonical filter string to restrict search results. The syntax of the canonical filter string is the same as SearchRequest.canonical_filter. Corresponds to the JSON property canonicalFilter

Returns:

  • (String)


4039
4040
4041
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4039

def canonical_filter
  @canonical_filter
end

#filterString

Optional. The filter string to restrict search results. The syntax of the filter string is the same as SearchRequest.filter. Corresponds to the JSON property filter

Returns:

  • (String)


4045
4046
4047
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4045

def filter
  @filter
end

#sort_byString

Optional. The sort string to specify the sorting of search results. The syntax of the sort string is the same as SearchRequest.sort. Corresponds to the JSON property sortBy

Returns:

  • (String)


4051
4052
4053
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4051

def sort_by
  @sort_by
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4058
4059
4060
4061
4062
4063
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4058

def update!(**args)
  @boost_spec = args[:boost_spec] if args.key?(:boost_spec)
  @canonical_filter = args[:canonical_filter] if args.key?(:canonical_filter)
  @filter = args[:filter] if args.key?(:filter)
  @sort_by = args[:sort_by] if args.key?(:sort_by)
end