Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchRequestUserAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

This field specifies the current user answer during the conversational filtering search. This can be either user selected from suggested answers or user input plain text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaConversationalSearchRequestUserAnswer

Returns a new instance of GoogleCloudRetailV2betaConversationalSearchRequestUserAnswer.



4083
4084
4085
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#selected_answerGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaConversationalSearchRequestUserAnswerSelectedAnswer

This field specifies the selected answers during the conversational search. Corresponds to the JSON property selectedAnswer



4075
4076
4077
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4075

def selected_answer
  @selected_answer
end

#text_answerString

This field specifies the incremental input text from the user during the conversational search. Corresponds to the JSON property textAnswer

Returns:

  • (String)


4081
4082
4083
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4081

def text_answer
  @text_answer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4088
4089
4090
4091
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4088

def update!(**args)
  @selected_answer = args[:selected_answer] if args.key?(:selected_answer)
  @text_answer = args[:text_answer] if args.key?(:text_answer)
end