Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExportAnalyticsMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExportAnalyticsMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Response of the ExportAnalyticsMetricsRequest. If the long running operation was successful, then this message is returned by the google.longrunning. Operations.response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExportErrorsConfig
Configuration of destination for Export related errors.
-
#output_result ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaOutputResult
Output result that stores the information about where the exported data is stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaExportAnalyticsMetricsResponse
constructor
A new instance of GoogleCloudRetailV2betaExportAnalyticsMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaExportAnalyticsMetricsResponse
Returns a new instance of GoogleCloudRetailV2betaExportAnalyticsMetricsResponse.
4505 4506 4507 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4505 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2beta::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
4492 4493 4494 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4492 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExportErrorsConfig
Configuration of destination for Export related errors.
Corresponds to the JSON property errorsConfig
4497 4498 4499 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4497 def errors_config @errors_config end |
#output_result ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaOutputResult
Output result that stores the information about where the exported data is
stored.
Corresponds to the JSON property outputResult
4503 4504 4505 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4503 def output_result @output_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4510 4511 4512 4513 4514 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4510 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @output_result = args[:output_result] if args.key?(:output_result) end |