Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response of the ExportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaExportUserEventsResponse

Returns a new instance of GoogleCloudRetailV2betaExportUserEventsResponse.



4690
4691
4692
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



4677
4678
4679
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4677

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaExportErrorsConfig

Configuration of destination for Export related errors. Corresponds to the JSON property errorsConfig



4682
4683
4684
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4682

def errors_config
  @errors_config
end

#output_resultGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaOutputResult

Output result that stores the information about where the exported data is stored. Corresponds to the JSON property outputResult



4688
4689
4690
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4688

def output_result
  @output_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4695
4696
4697
4698
4699
# File 'lib/google/apis/retail_v2beta/classes.rb', line 4695

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @output_result = args[:output_result] if args.key?(:output_result)
end