Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImportErrorsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Configuration of destination for Import related errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportErrorsConfig

Returns a new instance of GoogleCloudRetailV2betaImportErrorsConfig.



5023
5024
5025
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_prefixString

Google Cloud Storage prefix for import errors. This must be an empty, existing Cloud Storage directory. Import errors are written to sharded files in this directory, one per line, as a JSON-encoded google.rpc.Status message. Corresponds to the JSON property gcsPrefix

Returns:

  • (String)


5021
5022
5023
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5021

def gcs_prefix
  @gcs_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5028
5029
5030
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5028

def update!(**args)
  @gcs_prefix = args[:gcs_prefix] if args.key?(:gcs_prefix)
end