Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImportProductsRequest
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImportProductsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Request message for Import methods.
Instance Attribute Summary collapse
-
#errors_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImportErrorsConfig
Configuration of destination for Import related errors.
-
#input_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductInputConfig
The input config source for products.
-
#notification_pubsub_topic ⇒ String
Full Pub/Sub topic name for receiving notification.
-
#reconciliation_mode ⇒ String
The mode of reconciliation between existing products and the products to be imported.
-
#request_id ⇒ String
Deprecated.
-
#update_mask ⇒ String
Indicates which fields in the provided imported
productsto update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaImportProductsRequest
constructor
A new instance of GoogleCloudRetailV2betaImportProductsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaImportProductsRequest
Returns a new instance of GoogleCloudRetailV2betaImportProductsRequest.
5132 5133 5134 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImportErrorsConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorsConfig
5094 5095 5096 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5094 def errors_config @errors_config end |
#input_config ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductInputConfig
The input config source for products.
Corresponds to the JSON property inputConfig
5099 5100 5101 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5099 def input_config @input_config end |
#notification_pubsub_topic ⇒ String
Full Pub/Sub topic name for receiving notification. If this field is set, when
the import is finished, a notification is sent to specified Pub/Sub topic. The
message data is JSON string of a Operation. Format of the Pub/Sub topic is
projects/project/topics/topic`. It has to be within the same project as
ImportProductsRequest.parent. Make sure that bothcloud-retail-customer-data-
access@system.gserviceaccount.comandservice-@gcp-sa-retail.iam.
gserviceaccount.comhave thepubsub.topics.publishIAM permission on the
topic. Only supported when ImportProductsRequest.reconciliation_mode is set to
FULL.
Corresponds to the JSON propertynotificationPubsubTopic`
5112 5113 5114 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5112 def notification_pubsub_topic @notification_pubsub_topic end |
#reconciliation_mode ⇒ String
The mode of reconciliation between existing products and the products to be
imported. Defaults to ReconciliationMode.INCREMENTAL.
Corresponds to the JSON property reconciliationMode
5118 5119 5120 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5118 def reconciliation_mode @reconciliation_mode end |
#request_id ⇒ String
Deprecated. This field has no effect.
Corresponds to the JSON property requestId
5123 5124 5125 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5123 def request_id @request_id end |
#update_mask ⇒ String
Indicates which fields in the provided imported products to update. If not
set, all fields are updated. If provided, only the existing product fields are
updated. Missing products will not be created.
Corresponds to the JSON property updateMask
5130 5131 5132 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5130 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5137 5138 5139 5140 5141 5142 5143 5144 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5137 def update!(**args) @errors_config = args[:errors_config] if args.key?(:errors_config) @input_config = args[:input_config] if args.key?(:input_config) @notification_pubsub_topic = args[:notification_pubsub_topic] if args.key?(:notification_pubsub_topic) @reconciliation_mode = args[:reconciliation_mode] if args.key?(:reconciliation_mode) @request_id = args[:request_id] if args.key?(:request_id) @update_mask = args[:update_mask] if args.key?(:update_mask) end |