Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaImportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportUserEventsResponse

Returns a new instance of GoogleCloudRetailV2betaImportUserEventsResponse.



5221
5222
5223
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2beta::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



5208
5209
5210
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5208

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



5213
5214
5215
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5213

def errors_config
  @errors_config
end

#import_summaryGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaUserEventImportSummary

A summary of import result. The UserEventImportSummary summarizes the import status for user events. Corresponds to the JSON property importSummary



5219
5220
5221
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5219

def import_summary
  @import_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5226
5227
5228
5229
5230
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5226

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @import_summary = args[:import_summary] if args.key?(:import_summary)
end