Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaIntentClassificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaIntentClassificationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
The public proto to represent the intent classification config. It will be converted to the internal proto in the backend.
Instance Attribute Summary collapse
-
#blocklist_keywords ⇒ Array<String>
Optional.
-
#disabled_intent_types ⇒ Array<String>
Optional.
-
#example ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaIntentClassificationConfigExample>
Optional.
-
#inline_source ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaIntentClassificationConfigInlineSource
Inline source for intent classifications.
-
#model_preamble ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaIntentClassificationConfig
constructor
A new instance of GoogleCloudRetailV2betaIntentClassificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaIntentClassificationConfig
Returns a new instance of GoogleCloudRetailV2betaIntentClassificationConfig.
5250 5251 5252 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocklist_keywords ⇒ Array<String>
Optional. A list of keywords that will be used to classify the query to the "
BLOCKLISTED" intent type. The keywords are case insensitive.
Corresponds to the JSON property blocklistKeywords
5223 5224 5225 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5223 def blocklist_keywords @blocklist_keywords end |
#disabled_intent_types ⇒ Array<String>
Optional. A list of intent types that will be disabled for this customer. The
intent types must match one of the predefined intent types defined at https://
cloud.google.com/retail/docs/reference/rpc/google.cloud.retail.v2alpha#
querytype
Corresponds to the JSON property disabledIntentTypes
5231 5232 5233 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5231 def disabled_intent_types @disabled_intent_types end |
#example ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaIntentClassificationConfigExample>
Optional. A list of examples for intent classification.
Corresponds to the JSON property example
5236 5237 5238 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5236 def example @example end |
#inline_source ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaIntentClassificationConfigInlineSource
Inline source for intent classifications.
Corresponds to the JSON property inlineSource
5241 5242 5243 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5241 def inline_source @inline_source end |
#model_preamble ⇒ String
Optional. Customers can use the preamble to specify any requirements for
blocklisting intent classification. This preamble will be added to the
blocklisting intent classification model prompt.
Corresponds to the JSON property modelPreamble
5248 5249 5250 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5248 def model_preamble @model_preamble end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5255 5256 5257 5258 5259 5260 5261 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5255 def update!(**args) @blocklist_keywords = args[:blocklist_keywords] if args.key?(:blocklist_keywords) @disabled_intent_types = args[:disabled_intent_types] if args.key?(:disabled_intent_types) @example = args[:example] if args.key?(:example) @inline_source = args[:inline_source] if args.key?(:inline_source) @model_preamble = args[:model_preamble] if args.key?(:model_preamble) end |