Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaLocalInventory
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaLocalInventory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
The inventory information at a place (e.g. a store) identified by a place ID.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCustomAttribute>
Optional.
-
#fulfillment_types ⇒ Array<String>
Optional.
-
#place_id ⇒ String
Optional.
-
#price_info ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPriceInfo
The price information of a Product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaLocalInventory
constructor
A new instance of GoogleCloudRetailV2betaLocalInventory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaLocalInventory
Returns a new instance of GoogleCloudRetailV2betaLocalInventory.
5580 5581 5582 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Google::Apis::RetailV2beta::GoogleCloudRetailV2betaCustomAttribute>
Optional. Additional local inventory attributes, for example, store name,
promotion tags, etc. This field needs to pass all below criteria, otherwise an
INVALID_ARGUMENT error is returned: * At most 30 attributes are allowed. * The
key must be a UTF-8 encoded string with a length limit of 32 characters. * The
key must match the pattern: a-zA-Z0-9*. For example, key0LikeThis or
KEY_1_LIKE_THIS. * The attribute values must be of the same type (text or
number). * Only 1 value is allowed for each attribute. * For text values, the
length limit is 256 UTF-8 characters. * The attribute does not support search.
The searchable field should be unset or set to false. * The max summed total
bytes of custom attribute keys and values per product is 5MiB.
Corresponds to the JSON property attributes
5556 5557 5558 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5556 def attributes @attributes end |
#fulfillment_types ⇒ Array<String>
Optional. Supported fulfillment types. Valid fulfillment type values include
commonly used types (such as pickup in store and same day delivery), and
custom types. Customers have to map custom types to their display names before
rendering UI. Supported values: * "pickup-in-store" * "ship-to-store" * "same-
day-delivery" * "next-day-delivery" * "custom-type-1" * "custom-type-2" * "
custom-type-3" * "custom-type-4" * "custom-type-5" If this field is set to an
invalid value other than these, an INVALID_ARGUMENT error is returned. All the
elements must be distinct. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property fulfillmentTypes
5568 5569 5570 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5568 def fulfillment_types @fulfillment_types end |
#place_id ⇒ String
Optional. The place ID for the current set of inventory information.
Corresponds to the JSON property placeId
5573 5574 5575 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5573 def place_id @place_id end |
#price_info ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPriceInfo
The price information of a Product.
Corresponds to the JSON property priceInfo
5578 5579 5580 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5578 def price_info @price_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5585 5586 5587 5588 5589 5590 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 5585 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @fulfillment_types = args[:fulfillment_types] if args.key?(:fulfillment_types) @place_id = args[:place_id] if args.key?(:place_id) @price_info = args[:price_info] if args.key?(:price_info) end |