Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPanelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Detailed panel information associated with a user event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaPanelInfo

Returns a new instance of GoogleCloudRetailV2betaPanelInfo.



6083
6084
6085
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_tokenString

Optional. The attribution token of the panel. Corresponds to the JSON property attributionToken

Returns:

  • (String)


6054
6055
6056
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6054

def attribution_token
  @attribution_token
end

#display_nameString

Optional. The display name of the panel. Corresponds to the JSON property displayName

Returns:

  • (String)


6059
6060
6061
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6059

def display_name
  @display_name
end

#panel_idString

Required. The panel ID. Corresponds to the JSON property panelId

Returns:

  • (String)


6064
6065
6066
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6064

def panel_id
  @panel_id
end

#panel_positionFixnum

Optional. The ordered position of the panel, if shown to the user with other panels. If set, then total_panels must also be set. Corresponds to the JSON property panelPosition

Returns:

  • (Fixnum)


6070
6071
6072
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6070

def panel_position
  @panel_position
end

#product_detailsArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductDetail>

Optional. The product details associated with the panel. Corresponds to the JSON property productDetails



6075
6076
6077
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6075

def product_details
  @product_details
end

#total_panelsFixnum

Optional. The total number of panels, including this one, shown to the user. Must be set if panel_position is set. Corresponds to the JSON property totalPanels

Returns:

  • (Fixnum)


6081
6082
6083
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6081

def total_panels
  @total_panels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6088
6089
6090
6091
6092
6093
6094
6095
# File 'lib/google/apis/retail_v2beta/classes.rb', line 6088

def update!(**args)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @display_name = args[:display_name] if args.key?(:display_name)
  @panel_id = args[:panel_id] if args.key?(:panel_id)
  @panel_position = args[:panel_position] if args.key?(:panel_position)
  @product_details = args[:product_details] if args.key?(:product_details)
  @total_panels = args[:total_panels] if args.key?(:total_panels)
end