Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurchaseTransaction
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurchaseTransaction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
A transaction represents the entire purchase transaction.
Instance Attribute Summary collapse
-
#cost ⇒ Float
All the costs associated with the products.
-
#currency_code ⇒ String
Required.
-
#id ⇒ String
The transaction ID with a length limit of 128 characters.
-
#revenue ⇒ Float
Required.
-
#tax ⇒ Float
All the taxes associated with the transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaPurchaseTransaction
constructor
A new instance of GoogleCloudRetailV2betaPurchaseTransaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaPurchaseTransaction
Returns a new instance of GoogleCloudRetailV2betaPurchaseTransaction.
7046 7047 7048 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cost ⇒ Float
All the costs associated with the products. These can be manufacturing costs,
shipping expenses not borne by the end user, or any other costs, such that: *
Profit = revenue - tax - cost
Corresponds to the JSON property cost
7022 7023 7024 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7022 def cost @cost end |
#currency_code ⇒ String
Required. Currency code. Use three-character ISO-4217 code.
Corresponds to the JSON property currencyCode
7027 7028 7029 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7027 def currency_code @currency_code end |
#id ⇒ String
The transaction ID with a length limit of 128 characters.
Corresponds to the JSON property id
7032 7033 7034 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7032 def id @id end |
#revenue ⇒ Float
Required. Total non-zero revenue or grand total associated with the
transaction. This value include shipping, tax, or other adjustments to total
revenue that you want to include as part of your revenue calculations.
Corresponds to the JSON property revenue
7039 7040 7041 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7039 def revenue @revenue end |
#tax ⇒ Float
All the taxes associated with the transaction.
Corresponds to the JSON property tax
7044 7045 7046 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7044 def tax @tax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7051 7052 7053 7054 7055 7056 7057 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7051 def update!(**args) @cost = args[:cost] if args.key?(:cost) @currency_code = args[:currency_code] if args.key?(:currency_code) @id = args[:id] if args.key?(:id) @revenue = args[:revenue] if args.key?(:revenue) @tax = args[:tax] if args.key?(:tax) end |