Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurchaseTransaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

A transaction represents the entire purchase transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaPurchaseTransaction

Returns a new instance of GoogleCloudRetailV2betaPurchaseTransaction.



7065
7066
7067
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7065

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#costFloat

All the costs associated with the products. These can be manufacturing costs, shipping expenses not borne by the end user, or any other costs, such that: * Profit = revenue - tax - cost Corresponds to the JSON property cost

Returns:

  • (Float)


7041
7042
7043
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7041

def cost
  @cost
end

#currency_codeString

Required. Currency code. Use three-character ISO-4217 code. Corresponds to the JSON property currencyCode

Returns:

  • (String)


7046
7047
7048
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7046

def currency_code
  @currency_code
end

#idString

The transaction ID with a length limit of 128 characters. Corresponds to the JSON property id

Returns:

  • (String)


7051
7052
7053
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7051

def id
  @id
end

#revenueFloat

Required. Total non-zero revenue or grand total associated with the transaction. This value include shipping, tax, or other adjustments to total revenue that you want to include as part of your revenue calculations. Corresponds to the JSON property revenue

Returns:

  • (Float)


7058
7059
7060
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7058

def revenue
  @revenue
end

#taxFloat

All the taxes associated with the transaction. Corresponds to the JSON property tax

Returns:

  • (Float)


7063
7064
7065
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7063

def tax
  @tax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7070
7071
7072
7073
7074
7075
7076
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7070

def update!(**args)
  @cost = args[:cost] if args.key?(:cost)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @id = args[:id] if args.key?(:id)
  @revenue = args[:revenue] if args.key?(:revenue)
  @tax = args[:tax] if args.key?(:tax)
end