Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurgeUserEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurgeUserEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Request message for PurgeUserEvents method.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#force ⇒ Boolean
(also: #force?)
Actually perform the purge.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaPurgeUserEventsRequest
constructor
A new instance of GoogleCloudRetailV2betaPurgeUserEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaPurgeUserEventsRequest
Returns a new instance of GoogleCloudRetailV2betaPurgeUserEventsRequest.
7229 7230 7231 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. The filter string to specify the events to be deleted with a length
limit of 5,000 characters. Empty string filter is not allowed. The eligible
fields for filtering are: * eventType: Double quoted UserEvent.event_type
string. * eventTime: in ISO 8601 "zulu" format. * visitorId: Double quoted
string. Specifying this will delete all events associated with a visitor. *
userId: Double quoted string. Specifying this will delete all events
associated with a user. Examples: * Deleting all events in a time range:
eventTime > "2012-04-23T18:25:43.511Z" eventTime < "2012-04-23T18:30:43.511Z"
- Deleting specific eventType in time range:
eventTime > "2012-04-23T18:25:43. 511Z" eventType = "detail-page-view"* Deleting all events for a specific visitor:visitorId = "visitor1024"The filtering fields are assumed to have an implicit AND. Corresponds to the JSON propertyfilter
7220 7221 7222 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7220 def filter @filter end |
#force ⇒ Boolean Also known as: force?
Actually perform the purge. If force is set to false, the method will return
the expected purge count without deleting any user events.
Corresponds to the JSON property force
7226 7227 7228 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7226 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7234 7235 7236 7237 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7234 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) end |