Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPurgeUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response of the PurgeUserEventsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning. Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaPurgeUserEventsResponse

Returns a new instance of GoogleCloudRetailV2betaPurgeUserEventsResponse.



7251
7252
7253
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purged_events_countFixnum

The total count of events purged as a result of the operation. Corresponds to the JSON property purgedEventsCount

Returns:

  • (Fixnum)


7249
7250
7251
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7249

def purged_events_count
  @purged_events_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7256
7257
7258
# File 'lib/google/apis/retail_v2beta/classes.rb', line 7256

def update!(**args)
  @purged_events_count = args[:purged_events_count] if args.key?(:purged_events_count)
end