Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaSafetySetting

Returns a new instance of GoogleCloudRetailV2betaSafetySetting.



8082
8083
8084
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Harm category. Corresponds to the JSON property category

Returns:

  • (String)


8069
8070
8071
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8069

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


8075
8076
8077
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8075

def method_prop
  @method_prop
end

#thresholdString

The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


8080
8081
8082
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8080

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8087
8088
8089
8090
8091
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8087

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end