Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaSafetySetting

Returns a new instance of GoogleCloudRetailV2betaSafetySetting.



8101
8102
8103
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Harm category. Corresponds to the JSON property category

Returns:

  • (String)


8088
8089
8090
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8088

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


8094
8095
8096
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8094

def method_prop
  @method_prop
end

#thresholdString

The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


8099
8100
8101
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8099

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8106
8107
8108
8109
8110
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8106

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end