Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSafetySetting
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSafetySetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Safety settings.
Instance Attribute Summary collapse
-
#category ⇒ String
Harm category.
-
#method_prop ⇒ String
Optional.
-
#threshold ⇒ String
The harm block threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaSafetySetting
constructor
A new instance of GoogleCloudRetailV2betaSafetySetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaSafetySetting
Returns a new instance of GoogleCloudRetailV2betaSafetySetting.
8101 8102 8103 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Harm category.
Corresponds to the JSON property category
8088 8089 8090 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8088 def category @category end |
#method_prop ⇒ String
Optional. Specify if the threshold is used for probability or severity score.
If not specified, the threshold is used for probability score.
Corresponds to the JSON property method
8094 8095 8096 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8094 def method_prop @method_prop end |
#threshold ⇒ String
The harm block threshold.
Corresponds to the JSON property threshold
8099 8100 8101 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8099 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8106 8107 8108 8109 8110 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8106 def update!(**args) @category = args[:category] if args.key?(:category) @method_prop = args[:method_prop] if args.key?(:method_prop) @threshold = args[:threshold] if args.key?(:threshold) end |