Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestConversationalSearchSpec
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestConversationalSearchSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
This field specifies all conversational related parameters addition to traditional retail search.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
This field specifies the conversation id, which maintains the state of the conversation between client side and server side.
-
#followup_conversation_requested ⇒ Boolean
(also: #followup_conversation_requested?)
This field specifies whether the customer would like to do conversational search.
-
#user_answer ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestConversationalSearchSpecUserAnswer
This field specifies the current user answer during the conversational search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchRequestConversationalSearchSpec
constructor
A new instance of GoogleCloudRetailV2betaSearchRequestConversationalSearchSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchRequestConversationalSearchSpec
Returns a new instance of GoogleCloudRetailV2betaSearchRequestConversationalSearchSpec.
8464 8465 8466 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
This field specifies the conversation id, which maintains the state of the
conversation between client side and server side. Use the value from the
previous SearchResponse.ConversationalSearchResult.conversation_id. For the
initial request, this should be empty.
Corresponds to the JSON property conversationId
8446 8447 8448 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8446 def conversation_id @conversation_id end |
#followup_conversation_requested ⇒ Boolean Also known as: followup_conversation_requested?
This field specifies whether the customer would like to do conversational
search. If this field is set to true, conversational related extra information
will be returned from server side, including follow-up question, answer
options, etc.
Corresponds to the JSON property followupConversationRequested
8454 8455 8456 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8454 def followup_conversation_requested @followup_conversation_requested end |
#user_answer ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestConversationalSearchSpecUserAnswer
This field specifies the current user answer during the conversational search.
This can be either user selected from suggested answers or user input plain
text.
Corresponds to the JSON property userAnswer
8462 8463 8464 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8462 def user_answer @user_answer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8469 8470 8471 8472 8473 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8469 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @followup_conversation_requested = args[:followup_conversation_requested] if args.key?(:followup_conversation_requested) @user_answer = args[:user_answer] if args.key?(:user_answer) end |