Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestConversationalSearchSpecUserAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

This field specifies the current user answer during the conversational search. This can be either user selected from suggested answers or user input plain text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchRequestConversationalSearchSpecUserAnswer

Returns a new instance of GoogleCloudRetailV2betaSearchRequestConversationalSearchSpecUserAnswer.



8510
8511
8512
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#selected_answerGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestConversationalSearchSpecUserAnswerSelectedAnswer

This field specifies the selected answers during the conversational search. Corresponds to the JSON property selectedAnswer



8502
8503
8504
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8502

def selected_answer
  @selected_answer
end

#text_answerString

This field specifies the incremental input text from the user during the conversational search. Corresponds to the JSON property textAnswer

Returns:

  • (String)


8508
8509
8510
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8508

def text_answer
  @text_answer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8515
8516
8517
8518
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8515

def update!(**args)
  @selected_answer = args[:selected_answer] if args.key?(:selected_answer)
  @text_answer = args[:text_answer] if args.key?(:text_answer)
end