Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestFacetSpecFacetKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Specifies how a facet is computed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchRequestFacetSpecFacetKey

Returns a new instance of GoogleCloudRetailV2betaSearchRequestFacetSpecFacetKey.



8740
8741
8742
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#case_insensitiveBoolean Also known as: case_insensitive?

True to make facet keys case insensitive when getting faceting values with prefixes or contains; false otherwise. Corresponds to the JSON property caseInsensitive

Returns:

  • (Boolean)


8647
8648
8649
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8647

def case_insensitive
  @case_insensitive
end

#containsArray<String>

Only get facet values that contains the given strings. For example, suppose " categories" has three values "Women > Shoe", "Women > Dress" and "Men > Shoe". If set "contains" to "Shoe", the "categories" facet gives only "Women > Shoe" and "Men > Shoe". Only supported on textual fields. Maximum is 10. Corresponds to the JSON property contains

Returns:

  • (Array<String>)


8656
8657
8658
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8656

def contains
  @contains
end

#intervalsArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaInterval>

Set only if values should be bucketized into intervals. Must be set for facets with numerical values. Must not be set for facet with text values. Maximum number of intervals is 40. For all numerical facet keys that appear in the list of products from the catalog, the percentiles 0, 10, 30, 50, 70, 90, and 100 are computed from their distribution weekly. If the model assigns a high score to a numerical facet key and its intervals are not specified in the search request, these percentiles become the bounds for its intervals and are returned in the response. If the facet key intervals are specified in the request, then the specified intervals are returned instead. Corresponds to the JSON property intervals



8669
8670
8671
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8669

def intervals
  @intervals
end

#keyString

Required. Supported textual and numerical facet keys in Product object, over which the facet values are computed. Facet key is case-sensitive. Allowed facet keys when FacetKey.query is not specified: * textual_field = * "brands" * "categories" * "genders" * "ageGroups" * "availability" * "colorFamilies" * " colors" * "sizes" * "materials" * "patterns" * "conditions" * "attributes.key"

  • "pickupInStore" * "shipToStore" * "sameDayDelivery" * "nextDayDelivery" * " customFulfillment1" * "customFulfillment2" * "customFulfillment3" * " customFulfillment4" * "customFulfillment5" * "inventory(place_id,attributes. key)" * numerical_field = * "price" * "discount" * "rating" * "ratingCount" * " attributes.key" * "inventory(place_id,price)" * "inventory(place_id, original_price)" * "inventory(place_id,attributes.key)" Corresponds to the JSON property key

Returns:

  • (String)


8684
8685
8686
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8684

def key
  @key
end

#order_byString

The order in which SearchResponse.Facet.values are returned. Allowed values are: * "count desc", which means order by SearchResponse.Facet.values.count descending. * "value desc", which means order by SearchResponse.Facet.values. value descending. Only applies to textual facets. If not set, textual values are sorted in natural order ; numerical intervals are sorted in the order given by FacetSpec.FacetKey. intervals; FulfillmentInfo.place_ids are sorted in the order given by FacetSpec.FacetKey.restricted_values. Corresponds to the JSON property orderBy

Returns:

  • (String)


8696
8697
8698
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8696

def order_by
  @order_by
end

#prefixesArray<String>

Only get facet values that start with the given string prefix. For example, suppose "categories" has three values "Women > Shoe", "Women > Dress" and "Men

Shoe". If set "prefixes" to "Women", the "categories" facet gives only " Women > Shoe" and "Women > Dress". Only supported on textual fields. Maximum is 10. Corresponds to the JSON property prefixes

Returns:

  • (Array<String>)


8705
8706
8707
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8705

def prefixes
  @prefixes
end

#queryString

The query that is used to compute facet for the given facet key. When provided, it overrides the default behavior of facet computation. The query syntax is the same as a filter expression. See SearchRequest.filter for detail syntax and limitations. Notice that there is no limitation on FacetKey.key when query is specified. In the response, SearchResponse.Facet.values.value is always "1" and SearchResponse.Facet.values.count is the number of results that match the query. For example, you can set a customized facet for "shipToStore", where FacetKey.key is "customizedShipToStore", and FacetKey.query is "availability: ANY(\"IN_STOCK\") AND shipToStore: ANY(\"123\")". Then the facet counts the products that are both in stock and ship to store "123". Corresponds to the JSON property query

Returns:

  • (String)


8719
8720
8721
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8719

def query
  @query
end

#restricted_valuesArray<String>

Only get facet for the given restricted values. For example, when using " pickupInStore" as key and set restricted values to ["store123", "store456"], only facets for "store123" and "store456" are returned. Only supported on predefined textual fields, custom textual attributes and fulfillments. Maximum is 20. Must be set for the fulfillment facet keys: * pickupInStore * shipToStore * sameDayDelivery * nextDayDelivery * customFulfillment1 * customFulfillment2 * customFulfillment3 * customFulfillment4 * customFulfillment5 Corresponds to the JSON property restrictedValues

Returns:

  • (Array<String>)


8731
8732
8733
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8731

def restricted_values
  @restricted_values
end

#return_min_maxBoolean Also known as: return_min_max?

Returns the min and max value for each numerical facet intervals. Ignored for textual facets. Corresponds to the JSON property returnMinMax

Returns:

  • (Boolean)


8737
8738
8739
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8737

def return_min_max
  @return_min_max
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8745
8746
8747
8748
8749
8750
8751
8752
8753
8754
8755
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8745

def update!(**args)
  @case_insensitive = args[:case_insensitive] if args.key?(:case_insensitive)
  @contains = args[:contains] if args.key?(:contains)
  @intervals = args[:intervals] if args.key?(:intervals)
  @key = args[:key] if args.key?(:key)
  @order_by = args[:order_by] if args.key?(:order_by)
  @prefixes = args[:prefixes] if args.key?(:prefixes)
  @query = args[:query] if args.key?(:query)
  @restricted_values = args[:restricted_values] if args.key?(:restricted_values)
  @return_min_max = args[:return_min_max] if args.key?(:return_min_max)
end