Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestTileNavigationSpec
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestTileNavigationSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
This field specifies tile navigation related parameters.
Instance Attribute Summary collapse
-
#applied_tiles ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaTile>
This optional field specifies the tiles which are already clicked in client side.
-
#tile_navigation_requested ⇒ Boolean
(also: #tile_navigation_requested?)
This field specifies whether the customer would like to request tile navigation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchRequestTileNavigationSpec
constructor
A new instance of GoogleCloudRetailV2betaSearchRequestTileNavigationSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchRequestTileNavigationSpec
Returns a new instance of GoogleCloudRetailV2betaSearchRequestTileNavigationSpec.
8830 8831 8832 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_tiles ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaTile>
This optional field specifies the tiles which are already clicked in client
side. While the feature works without this field set, particularly for an
initial query, it is highly recommended to set this field because it can
improve the quality of the search response and removes possible duplicate
tiles. NOTE: This field is not being used for filtering search products.
Client side should also put all the applied tiles in SearchRequest.filter.
Corresponds to the JSON property appliedTiles
8821 8822 8823 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8821 def applied_tiles @applied_tiles end |
#tile_navigation_requested ⇒ Boolean Also known as:
This field specifies whether the customer would like to request tile
navigation.
Corresponds to the JSON property tileNavigationRequested
8827 8828 8829 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8827 def @tile_navigation_requested end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8835 8836 8837 8838 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8835 def update!(**args) @applied_tiles = args[:applied_tiles] if args.key?(:applied_tiles) @tile_navigation_requested = args[:tile_navigation_requested] if args.key?(:tile_navigation_requested) end |