Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
Response message for SearchService.Search method.
Instance Attribute Summary collapse
-
#applied_controls ⇒ Array<String>
The fully qualified resource name of applied controls.
-
#attribution_token ⇒ String
A unique search token.
-
#conversational_search_result ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseConversationalSearchResult
This field specifies all related information that is needed on client side for UI rendering of conversational retail search.
-
#corrected_query ⇒ String
Contains the spell corrected query, if found.
-
#experiment_info ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExperimentInfo>
Metadata related to A/B testing experiment associated with this response.
-
#facets ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseFacet>
Results of facets requested by user.
-
#invalid_condition_boost_specs ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestBoostSpecConditionBoostSpec>
The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied during serving.
-
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
-
#pin_control_metadata ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPinControlMetadata
Metadata for pinning to be returned in the response.
-
#query_expansion_info ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has occurred.
-
#redirect_uri ⇒ String
The URI of a customer-defined redirect page.
-
#results ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseSearchResult>
A list of matched items.
-
#tile_navigation_result ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseTileNavigationResult
This field specifies all related information for tile navigation that will be used in client side.
-
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchResponse
constructor
A new instance of GoogleCloudRetailV2betaSearchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchResponse
Returns a new instance of GoogleCloudRetailV2betaSearchResponse.
8932 8933 8934 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_controls ⇒ Array<String>
The fully qualified resource name of applied controls.
Corresponds to the JSON property appliedControls
8849 8850 8851 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8849 def applied_controls @applied_controls end |
#attribution_token ⇒ String
A unique search token. This should be included in the UserEvent logs resulting
from this search, which enables accurate attribution of search model
performance.
Corresponds to the JSON property attributionToken
8856 8857 8858 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8856 def attribution_token @attribution_token end |
#conversational_search_result ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseConversationalSearchResult
This field specifies all related information that is needed on client side for
UI rendering of conversational retail search.
Corresponds to the JSON property conversationalSearchResult
8862 8863 8864 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8862 def conversational_search_result @conversational_search_result end |
#corrected_query ⇒ String
Contains the spell corrected query, if found. The search results are based on
corrected_query by default. However, if SearchRequest.SpellCorrectionSpec.mode
is set to SearchRequest.SpellCorrectionSpec.Mode.SUGGESTION_ONLY, the original
query is used for search.
Corresponds to the JSON property correctedQuery
8870 8871 8872 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8870 def corrected_query @corrected_query end |
#experiment_info ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExperimentInfo>
Metadata related to A/B testing experiment associated with this response. Only
exists when an experiment is triggered.
Corresponds to the JSON property experimentInfo
8876 8877 8878 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8876 def experiment_info @experiment_info end |
#facets ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseFacet>
Results of facets requested by user.
Corresponds to the JSON property facets
8881 8882 8883 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8881 def facets @facets end |
#invalid_condition_boost_specs ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestBoostSpecConditionBoostSpec>
The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied
during serving.
Corresponds to the JSON property invalidConditionBoostSpecs
8887 8888 8889 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8887 def invalid_condition_boost_specs @invalid_condition_boost_specs end |
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
8893 8894 8895 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8893 def next_page_token @next_page_token end |
#pin_control_metadata ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaPinControlMetadata
Metadata for pinning to be returned in the response. This is used for
distinguishing between applied vs dropped pins.
Corresponds to the JSON property pinControlMetadata
8899 8900 8901 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8899 def @pin_control_metadata end |
#query_expansion_info ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has
occurred.
Corresponds to the JSON property queryExpansionInfo
8905 8906 8907 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8905 def query_expansion_info @query_expansion_info end |
#redirect_uri ⇒ String
The URI of a customer-defined redirect page. If redirect action is triggered,
no search is performed, and only redirect_uri and attribution_token are set in
the response.
Corresponds to the JSON property redirectUri
8912 8913 8914 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8912 def redirect_uri @redirect_uri end |
#results ⇒ Array<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseSearchResult>
A list of matched items. The order represents the ranking.
Corresponds to the JSON property results
8917 8918 8919 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8917 def results @results end |
#tile_navigation_result ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseTileNavigationResult
This field specifies all related information for tile navigation that will be
used in client side.
Corresponds to the JSON property tileNavigationResult
8923 8924 8925 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8923 def @tile_navigation_result end |
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination. The
count of results returned by pagination may be less than the total_size that
matches.
Corresponds to the JSON property totalSize
8930 8931 8932 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8930 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8937 8938 8939 8940 8941 8942 8943 8944 8945 8946 8947 8948 8949 8950 8951 8952 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8937 def update!(**args) @applied_controls = args[:applied_controls] if args.key?(:applied_controls) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @conversational_search_result = args[:conversational_search_result] if args.key?(:conversational_search_result) @corrected_query = args[:corrected_query] if args.key?(:corrected_query) @experiment_info = args[:experiment_info] if args.key?(:experiment_info) @facets = args[:facets] if args.key?(:facets) @invalid_condition_boost_specs = args[:invalid_condition_boost_specs] if args.key?(:invalid_condition_boost_specs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @pin_control_metadata = args[:pin_control_metadata] if args.key?(:pin_control_metadata) @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @results = args[:results] if args.key?(:results) @tile_navigation_result = args[:tile_navigation_result] if args.key?(:tile_navigation_result) @total_size = args[:total_size] if args.key?(:total_size) end |