Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

Response message for SearchService.Search method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchResponse

Returns a new instance of GoogleCloudRetailV2betaSearchResponse.



8948
8949
8950
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_controlsArray<String>

The fully qualified resource name of applied controls. Corresponds to the JSON property appliedControls

Returns:

  • (Array<String>)


8866
8867
8868
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8866

def applied_controls
  @applied_controls
end

#attribution_tokenString

A unique search token. This should be included in the UserEvent logs resulting from this search, which enables accurate attribution of search model performance. Corresponds to the JSON property attributionToken

Returns:

  • (String)


8873
8874
8875
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8873

def attribution_token
  @attribution_token
end

#conversational_search_resultGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseConversationalSearchResult

This field specifies all related information that is needed on client side for UI rendering of conversational retail search. Corresponds to the JSON property conversationalSearchResult



8879
8880
8881
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8879

def conversational_search_result
  @conversational_search_result
end

#corrected_queryString

Contains the spell corrected query, if found. If the spell correction type is AUTOMATIC, then the search results are based on corrected_query. Otherwise the original query is used for search. Corresponds to the JSON property correctedQuery

Returns:

  • (String)


8886
8887
8888
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8886

def corrected_query
  @corrected_query
end

#experiment_infoArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaExperimentInfo>

Metadata related to A/B testing experiment associated with this response. Only exists when an experiment is triggered. Corresponds to the JSON property experimentInfo



8892
8893
8894
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8892

def experiment_info
  @experiment_info
end

#facetsArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseFacet>

Results of facets requested by user. Corresponds to the JSON property facets



8897
8898
8899
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8897

def facets
  @facets
end

#invalid_condition_boost_specsArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchRequestBoostSpecConditionBoostSpec>

The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied during serving. Corresponds to the JSON property invalidConditionBoostSpecs



8903
8904
8905
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8903

def invalid_condition_boost_specs
  @invalid_condition_boost_specs
end

#next_page_tokenString

A token that can be sent as SearchRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8909
8910
8911
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8909

def next_page_token
  @next_page_token
end

#pin_control_metadataGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaPinControlMetadata

Metadata for pinning to be returned in the response. This is used for distinguishing between applied vs dropped pins. Corresponds to the JSON property pinControlMetadata



8915
8916
8917
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8915

def 
  @pin_control_metadata
end

#query_expansion_infoGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseQueryExpansionInfo

Information describing query expansion including whether expansion has occurred. Corresponds to the JSON property queryExpansionInfo



8921
8922
8923
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8921

def query_expansion_info
  @query_expansion_info
end

#redirect_uriString

The URI of a customer-defined redirect page. If redirect action is triggered, no search is performed, and only redirect_uri and attribution_token are set in the response. Corresponds to the JSON property redirectUri

Returns:

  • (String)


8928
8929
8930
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8928

def redirect_uri
  @redirect_uri
end

#resultsArray<Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseSearchResult>

A list of matched items. The order represents the ranking. Corresponds to the JSON property results



8933
8934
8935
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8933

def results
  @results
end

#tile_navigation_resultGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseTileNavigationResult

This field specifies all related information for tile navigation that will be used in client side. Corresponds to the JSON property tileNavigationResult



8939
8940
8941
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8939

def tile_navigation_result
  @tile_navigation_result
end

#total_sizeFixnum

The estimated total count of matched items irrespective of pagination. The count of results returned by pagination may be less than the total_size that matches. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


8946
8947
8948
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8946

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
8967
8968
# File 'lib/google/apis/retail_v2beta/classes.rb', line 8953

def update!(**args)
  @applied_controls = args[:applied_controls] if args.key?(:applied_controls)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @conversational_search_result = args[:conversational_search_result] if args.key?(:conversational_search_result)
  @corrected_query = args[:corrected_query] if args.key?(:corrected_query)
  @experiment_info = args[:experiment_info] if args.key?(:experiment_info)
  @facets = args[:facets] if args.key?(:facets)
  @invalid_condition_boost_specs = args[:invalid_condition_boost_specs] if args.key?(:invalid_condition_boost_specs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @pin_control_metadata = args[:pin_control_metadata] if args.key?(:pin_control_metadata)
  @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @results = args[:results] if args.key?(:results)
  @tile_navigation_result = args[:tile_navigation_result] if args.key?(:tile_navigation_result)
  @total_size = args[:total_size] if args.key?(:total_size)
end