Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaSearchResponseFacetFacetValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb

Overview

A facet value which contains value names and their count.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaSearchResponseFacetFacetValue

Returns a new instance of GoogleCloudRetailV2betaSearchResponseFacetFacetValue.



9136
9137
9138
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Number of items that have this facet value. Corresponds to the JSON property count

Returns:

  • (Fixnum)


9112
9113
9114
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9112

def count
  @count
end

#intervalGoogle::Apis::RetailV2beta::GoogleCloudRetailV2betaInterval

A floating point interval. Corresponds to the JSON property interval



9117
9118
9119
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9117

def interval
  @interval
end

#max_valueFloat

The maximum value in the FacetValue.interval. Only supported on numerical facets and returned if SearchRequest.FacetSpec.FacetKey.return_min_max is true. Corresponds to the JSON property maxValue

Returns:

  • (Float)


9123
9124
9125
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9123

def max_value
  @max_value
end

#min_valueFloat

The minimum value in the FacetValue.interval. Only supported on numerical facets and returned if SearchRequest.FacetSpec.FacetKey.return_min_max is true. Corresponds to the JSON property minValue

Returns:

  • (Float)


9129
9130
9131
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9129

def min_value
  @min_value
end

#valueString

Text value of a facet, such as "Black" for facet "colorFamilies". Corresponds to the JSON property value

Returns:

  • (String)


9134
9135
9136
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9134

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9141
9142
9143
9144
9145
9146
9147
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9141

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @interval = args[:interval] if args.key?(:interval)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
  @value = args[:value] if args.key?(:value)
end