Class: Google::Apis::RetailV2beta::GoogleCloudRetailV2betaTile
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2beta::GoogleCloudRetailV2betaTile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2beta/classes.rb,
lib/google/apis/retail_v2beta/representations.rb,
lib/google/apis/retail_v2beta/representations.rb
Overview
This field specifies the tile information including an attribute key, attribute value. More fields will be added in the future, eg: product id or product counts, etc.
Instance Attribute Summary collapse
-
#product_attribute_interval ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeInterval
Product attribute name and numeric interval.
-
#product_attribute_value ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeValue
Product attribute which structured by an attribute name and value.
-
#representative_product_id ⇒ String
The representative product id for this tile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaTile
constructor
A new instance of GoogleCloudRetailV2betaTile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaTile
Returns a new instance of GoogleCloudRetailV2betaTile.
9626 9627 9628 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_attribute_interval ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeInterval
Product attribute name and numeric interval.
Corresponds to the JSON property productAttributeInterval
9612 9613 9614 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9612 def product_attribute_interval @product_attribute_interval end |
#product_attribute_value ⇒ Google::Apis::RetailV2beta::GoogleCloudRetailV2betaProductAttributeValue
Product attribute which structured by an attribute name and value. This
structure is used in conversational search filters and answers. For example,
if we have name=color and value=red, this means that the color is red.
Corresponds to the JSON property productAttributeValue
9619 9620 9621 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9619 def product_attribute_value @product_attribute_value end |
#representative_product_id ⇒ String
The representative product id for this tile.
Corresponds to the JSON property representativeProductId
9624 9625 9626 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9624 def representative_product_id @representative_product_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9631 9632 9633 9634 9635 |
# File 'lib/google/apis/retail_v2beta/classes.rb', line 9631 def update!(**args) @product_attribute_interval = args[:product_attribute_interval] if args.key?(:product_attribute_interval) @product_attribute_value = args[:product_attribute_value] if args.key?(:product_attribute_value) @representative_product_id = args[:representative_product_id] if args.key?(:representative_product_id) end |